<?php
include 'conn.php';

// Handle form submission for adding or updating menu items
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['submit_menu'])) {
        $name = $_POST['name'];
        $icon = $_POST['icon'];
        $link = $_POST['link'];
        $status = $_POST['status'];
        $id = $_POST['id'];
        $order = $_POST['order']; // Add order input

        // Handle file upload for the image
        if (isset($_FILES['image']) && $_FILES['image']['error'] === UPLOAD_ERR_OK) {
            $file = $_FILES['image'];
            $uploadDir = '../dist/img/'; // Directory for file upload
            $uploadFile = $uploadDir . basename($file['name']);

            if (move_uploaded_file($file['tmp_name'], $uploadFile)) {
                $imagePath = './dist/img/' . basename($file['name']); // Store as relative path
            } else {
                $error = "Failed to move uploaded file.";
                $imagePath = ''; // Ensure $imagePath is set to avoid errors
            }
        } else {
            $imagePath = $_POST['existing_image'] ?? ''; // Use the existing image if no new file is uploaded
        }

        if ($id) {
            // Update existing menu item
            $sql = "UPDATE navbars SET name = ?, icon = ?, link = ?, status = ?, image = ?, `order` = ? WHERE id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->execute([$name, $icon, $link, $status, $imagePath, $order, $id]);
        } else {
            // Add new menu item
            $sql = "INSERT INTO navbars (name, icon, link, status, image, `order`) VALUES (?, ?, ?, ?, ?, ?)";
            $stmt = $conn->prepare($sql);
            $stmt->execute([$name, $icon, $link, $status, $imagePath, $order]);
        }

        // Redirect to the same page after form submission
        header("Location: admin.php");
        exit();
    }

    // Handle delete request
    if (isset($_GET['deletenav'])) {
        $id = intval($_GET['deletenav']); // Sanitize the input

        if ($id > 0) {
            // Prepare the delete statement
            $sql = "DELETE FROM navbars WHERE id = ?";
            $stmt = $conn->prepare($sql);

            if ($stmt->execute([$id])) {
                // Redirect to the same page after deletion
                header("Location: admin.php");
                exit();
            } else {
                echo "Error executing query: " . implode(":", $stmt->errorInfo());
            }
        } else {
            echo "Invalid ID provided.";
        }
    }

    // Handle reordering request
    if (isset($_POST['reorder_menu'])) {
        $orders = $_POST['order']; // Array of new order values

        foreach ($orders as $id => $order) {
            // Update the order value for each menu item
            $stmt = $conn->prepare("UPDATE navbars SET `order` = ? WHERE id = ?");
            $stmt->execute([$order, $id]);
        }

        // Redirect to avoid re-submission
        header("Location: admin.php");
        exit();
    }
}

// Fetch existing menu items sorted by order
$stmt = $conn->query("SELECT * FROM navbars ORDER BY `order` ASC");
$menuItems = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Pre-fill form for editing if `edit` parameter is set
$editItem = null;
if (isset($_GET['edit'])) {
    $id = $_GET['edit'];
    $stmt = $conn->prepare("SELECT * FROM navbars WHERE id = ?");
    $stmt->execute([$id]);
    $editItem = $stmt->fetch(PDO::FETCH_ASSOC);
}
// Handle delete request for cover picture
if (isset($_GET['delete_cover'])) {
    $stmt = $conn->query("SELECT * FROM cover_pic ORDER BY id DESC LIMIT 1");
    $coverPic = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($coverPic) {
        unlink($coverPic['image_path']); // Remove cover image from the directory
        $sql = "DELETE FROM cover_pic WHERE id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->execute([$coverPic['id']]);
    }

    // Redirect to the same page after deletion
    header("Location: admin.php");
    exit();
}

// Fetch existing menu items
$stmt = $conn->query("SELECT * FROM navbars");
$menuItems = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Fetch the cover picture
$stmt = $conn->query("SELECT * FROM cover_pic ORDER BY id DESC LIMIT 1");
$coverPic = $stmt->fetch(PDO::FETCH_ASSOC);

// Handle form submission for adding records
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'add') {
    // Retrieve form data
    $description = $_POST['description'];
    $image = $_FILES['image'];

    // Process image upload
    $targetDir = '../dist/img/'; // Server-side path where images are stored
    $imagePath = 'default-image.jpg'; // Default image path

    if ($image['error'] == UPLOAD_ERR_OK) {
        // Define the target directory and file path
        $targetFile = $targetDir . basename($image['name']);
        
        // Move the uploaded file to the target directory
        if (move_uploaded_file($image['tmp_name'], $targetFile)) {
            $imagePath = './dist/img/' . basename($image['name']); // Path to be stored in DB
        } else {
            echo "<script>alert('Failed to upload image'); window.location.href='admin.php';</script>";
        }
    }

    // Insert data into the database
    $stmt = $conn->prepare("INSERT INTO analysis (description, image) VALUES (:description, :image)");
    $stmt->execute([
        ':description' => $description,
        ':image' => $imagePath
    ]);

    echo "<script>alert('Record inserted successfully!'); window.location.href='admin.php';</script>"; 'Data successfully inserted.';
}

// Handle delete requests
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'delete') {
    $id = $_POST['id'];

    // Fetch the image path to delete it
    $stmt = $conn->prepare("SELECT image FROM analysis WHERE id = :id");
    $stmt->execute([':id' => $id]);
    $record = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($record) {
        // Delete the image file if it exists
        $imagePath = '../' . $record['image']; // Adjust for admin side path
        if (file_exists($imagePath) && $imagePath != '../dist/img/default-image.jpg') {
            unlink($imagePath);
        }

        // Delete the record from the database
        $stmt = $conn->prepare("DELETE FROM analysis WHERE id = :id");
        $stmt->execute([':id' => $id]);

        echo "<script>alert('Record successfully deleted !'); window.location.href='admin.php';</script>";
    }
}

// Fetch all records from the analysis table
$stmt = $conn->query("SELECT * FROM analysis");
$analysisItems = $stmt->fetchAll(PDO::FETCH_ASSOC);


// Handle video addition
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['add_video'])) {
    // Retrieve form data
    $videoId = $_POST['video_id'];
    $title = $_POST['title'];
    $description = $_POST['description'];
    $thumbnail = $_POST['thumbnail'];

    // Insert data into the videos table
    $stmt = $conn->prepare("INSERT INTO videos (video_id, title, description, thumbnail) VALUES (:video_id, :title, :description, :thumbnail)");
    $stmt->execute([
        ':video_id' => $videoId,
        ':title' => $title,
        ':description' => $description,
        ':thumbnail' => $thumbnail
    ]);

    echo "<script>alert('Video successfully added!'); window.location.href='admin.php';</script>";
}

// Handle video deletion
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['delete_video'])) {
    $videoId = $_POST['video_id'];

    // Delete data from the videos table
    $stmt = $conn->prepare("DELETE FROM videos WHERE video_id = :video_id");
    $stmt->execute([':video_id' => $videoId]);

    echo "<script>alert('Modal content deleted successfully!'); window.location.href='admin.php';</script>";
}

// Fetch videos from the videos table
$stmt = $conn->query("SELECT * FROM videos");
$videos = $stmt->fetchAll(PDO::FETCH_ASSOC);


// Handle form submission for inserting or updating modal content
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['save'])) {
        $message = $_POST['message'];

        // Check if there's an existing entry
        $stmt = $conn->query("SELECT COUNT(*) AS count FROM modal_content");
        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($row['count'] > 0) {
            // Update existing record
            $stmt = $conn->prepare("UPDATE modal_content SET message = :message ORDER BY id DESC LIMIT 1");
        } else {
            // Insert new record
            $stmt = $conn->prepare("INSERT INTO modal_content (message) VALUES (:message)");
        }
        
        $stmt->execute(['message' => $message]);
        echo "<script>alert('Modal content updated successfully!'); window.location.href='admin.php';</script>";
    } elseif (isset($_POST['delete'])) {
        // Delete the existing record
        $stmt = $conn->prepare("DELETE FROM modal_content ORDER BY id DESC LIMIT 1");
        $stmt->execute();
        echo "<script>alert('Modal content deleted successfully!'); window.location.href='admin.php';</script>";
    }
}

// Fetch current modal content for editing
$stmt = $conn->query("SELECT message FROM modal_content ORDER BY id DESC LIMIT 1");
$modalContent = $stmt->fetch(PDO::FETCH_ASSOC);
$currentMessage = $modalContent['message'] ?? '';

// Handle update request
if (isset($_POST['update'])) {
    $stmt = $conn->prepare("UPDATE footer SET copyright_message = ?, event_info = ? WHERE id = ?");
    $stmt->execute([$_POST['copyright_message'], $_POST['event_info'], $_POST['id']]);

    echo "<script>alert('Footer content updated successfully!'); window.location.href='admin.php';</script>";
}

// Handle deletion request
if (isset($_POST['delete'])) {
    $stmt = $conn->prepare("DELETE FROM footer WHERE id = ?");
    $stmt->execute([$_POST['id']]);

    echo "<script>alert('Footer content deleted successfully!'); window.location.href='admin.php';</script>";
}

// Fetch footer content from the footer table
$stmt = $conn->query("SELECT * FROM footer ORDER BY id DESC LIMIT 1");
$footer = $stmt->fetch(PDO::FETCH_ASSOC);
$copyrightMessage = $footer['copyright_message'] ?? '&copy; ' . date('Y') . ' Directorate of Teens and Children Education.';
$eventInfo = $footer['event_info'] ?? 'CO-ORDINATOR\'S EVENT REGISTRATION PORTAL v.1.0.0';

// Fetch products from the database
$query = "SELECT id, name, description, price, image_path, slug FROM products";
$stmt = $conn->prepare($query);
$stmt->execute();
$products = $stmt->fetchAll(PDO::FETCH_ASSOC);


// Handle product deletion
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'delete') {
    $productId = $_POST['id'];
    $deleteQuery = "DELETE FROM products WHERE id = ?";
    $deleteStmt = $conn->prepare($deleteQuery);
    $deleteStmt->execute([$productId]);
    header("Location: admin.php"); // Redirect to avoid form resubmission
    exit;
}



// Handle adding a new product
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_product']) && $_POST['add_product'] == 1) {
    $name = $_POST['name'];
    $description = $_POST['description'];
    $price = $_POST['price'];

    // Generate slug from the product name
    $slug = strtolower(trim(preg_replace('/[^A-Za-z0-9-]+/', '-', $name)));

    // Define upload and web directory paths
    $uploadDir = '../products/'; // Directory where the image will be uploaded
    $webDir = './products/';     // Path to be stored in the database

    // Handle file upload
    if (isset($_FILES['image']) && $_FILES['image']['error'] === UPLOAD_ERR_OK) {
        $fileTmpPath = $_FILES['image']['tmp_name'];
        $fileName = $_FILES['image']['name'];
        $fileNameCmps = explode(".", $fileName);
        $fileExtension = strtolower(end($fileNameCmps));

        // Define allowed file extensions
        $allowedExts = array('jpg', 'jpeg', 'png', 'gif');

        if (in_array($fileExtension, $allowedExts)) {
            // Generate a unique file name and set the upload path
            $newFileName = md5(time() . $fileName) . '.' . $fileExtension;
            $uploadFilePath = $uploadDir . $newFileName;

            // Move the file to the desired directory
            if (move_uploaded_file($fileTmpPath, $uploadFilePath)) {
                // Store the web-accessible path in the database
                $imagePath = $webDir . $newFileName;
            } else {
                echo "<script>alert('Error uploading the file.'); window.location.href='admin.php';</script>";
                exit;
            }
        } else {
            echo "<script>alert('Invalid file type.'); window.location.href='admin.php';</script>";
            exit;
        }
    } else {
        echo "<script>alert('No file uploaded or there was an upload error.'); window.location.href='admin.php';</script>";
        exit;
    }

    // Insert product details including slug into the database
    $insertQuery = "INSERT INTO products (name, description, price, image_path, slug) VALUES (?, ?, ?, ?, ?)";
    $insertStmt = $conn->prepare($insertQuery);
    $insertStmt->execute([$name, $description, $price, $imagePath, $slug]);

    // Redirect to avoid form resubmission
    echo "<script>alert('Product added successfully.'); window.location.href='admin.php';</script>";
    exit;
}
// Fetch all product types
$stmt = $conn->query("SELECT * FROM product_types");
$productTypes = $stmt->fetchAll(PDO::FETCH_ASSOC);


// Handle Add Product Type
if (isset($_POST['add'])) {
    $type = htmlspecialchars(trim($_POST['type']));

    $stmt = $conn->prepare("INSERT INTO product_types (type) VALUES (?)");
    if ($stmt->execute([$type])) {
        header("Location: admin.php");
        exit();
    } else {
        echo '<script>alert("Failed to add product type.");</script>';
    }
}

// Handle Update Product Type
if (isset($_POST['update'])) {
    $id = intval($_POST['id']);
    $type = htmlspecialchars(trim($_POST['type']));

    $stmt = $conn->prepare("UPDATE product_types SET type = ? WHERE id = ?");
    if ($stmt->execute([$type, $id])) {
        header("Location: admin.php");
        exit();
    } else {
        echo '<script>alert("Failed to update product type.");</script>';
    }
}

// Handle Delete Product Type
if (isset($_GET['delete'])) {
    $id = intval($_GET['delete']);

    $stmt = $conn->prepare("DELETE FROM product_types WHERE id = ?");
    if ($stmt->execute([$id])) {
        header("Location: admin.php");
        exit();
    } else {
        echo '<script>alert("Failed to delete product type.");</script>';
    }
}



$uploadDir = '../events/'; // Directory for storing uploaded images

// Handle form submission for adding or editing events
if ($_SERVER['REQUEST_METHOD'] == 'POST'&& isset($_POST['upcomingevent'])) {
    $eventName = $_POST['event_name'];
    $eventDetails = $_POST['event_details'];
    $eventDate = $_POST['event_date'];
    $eventLink = filter_var($_POST['event_link'], FILTER_SANITIZE_URL);
    // Validate URL
    if (filter_var($eventLink, FILTER_VALIDATE_URL) === FALSE) {
        echo "Invalid URL.";
    } else {
        // Process the valid URL
        echo "Valid URL: " . htmlspecialchars($eventLink);
    }
    $buttonText = $_POST['button_text'];
    $buttonActive = isset($_POST['button_active']) ? 1 : 0;
    $eventId = isset($_POST['event_id']) ? $_POST['event_id'] : null;

    $imagePath = '';

    // Handle image upload if a file is provided
    if (!empty($_FILES['event_image']['name'])) {
        $imageName = basename($_FILES['event_image']['name']);
        $targetFile = $uploadDir . $imageName;

        if (move_uploaded_file($_FILES['event_image']['tmp_name'], $targetFile)) {
            $imagePath = './events/' . $imageName; // Path for public view
        } else {
            echo "Failed to upload image.";
        }
    }

    // Insert or update event in the database
    try {
        if ($eventId) {
            // Update event
            $query = "UPDATE upcomingevents SET event_name = ?, event_details = ?, event_date = ?, event_link = ?, button_text = ?, button_active = ?";
            if ($imagePath) {
                $query .= ", event_image = ?";
            }
            $query .= " WHERE id = ?";
            $stmt = $conn->prepare($query);
            if ($imagePath) {
                $stmt->execute([$eventName, $eventDetails, $eventDate, $eventLink, $buttonText, $buttonActive, $imagePath, $eventId]);
            } else {
                $stmt->execute([$eventName, $eventDetails, $eventDate, $eventLink, $buttonText, $buttonActive, $eventId]);
            }
        } else {
            // Insert new event
            $stmt = $conn->prepare("INSERT INTO upcomingevents (event_name, event_details, event_date, event_link, button_text, button_active, event_image) VALUES (?, ?, ?, ?, ?, ?, ?)");
            $stmt->execute([$eventName, $eventDetails, $eventDate, $eventLink, $buttonText, $buttonActive, $imagePath]);
        }

        header("Location: admin.php");
        exit;

    } catch (PDOException $e) {
        echo "Error: " . $e->getMessage();
    }
}

// Handle deletion of events
if (isset($_GET['deleteevent'])) {
    $eventId = $_GET['deleteevent'];

    try {
        $stmt = $conn->prepare("DELETE FROM upcomingevents WHERE id = ?");
        $stmt->execute([$eventId]);

        header("Location: admin.php");
        exit;

    } catch (PDOException $e) {
        echo "Error: " . $e->getMessage();
    }
}



// Fetch all events for display in the admin panel
try {
    $stmt = $conn->query("SELECT * FROM upcomingevents ORDER BY event_date ASC");
    $events = $stmt->fetchAll(PDO::FETCH_ASSOC);

} catch (PDOException $e) {
    echo "Database error: " . $e->getMessage();
}

// Check if an edit ID is present
// Handle editing of events
if (isset($_GET['editevent'])) {
    $eventId = $_GET['editevent'];

    // Fetch event details from the database for editing
    $stmt = $conn->prepare("SELECT * FROM upcomingevents WHERE id = ?");
    $stmt->execute([$eventId]);
    $event = $stmt->fetch(PDO::FETCH_ASSOC);
    // Use $event data to populate your edit form
}
// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['notification'])) {
    $province = $_POST['province'];
    $message = $_POST['message'];

    // Insert the notification into the database
    $stmt = $conn->prepare("INSERT INTO notifications (province, message) VALUES (:province, :message)");
    $stmt->bindValue(':province', $province);
    $stmt->bindValue(':message', $message);
    
    if ($stmt->execute()) {
        $successMessage = "Notification sent successfully!";
    } else {
        $errorMessage = "Failed to send notification.";
    }
}


/// Initialize variables for messages and form data
$successMessage = '';
$errorMessage = '';
$meetings = [];

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['meetings'])) {
    // Retrieve form data
    $title = htmlspecialchars(trim($_POST['title']));
    $meeting_id = htmlspecialchars(trim($_POST['meeting_id']));
    $speaker_name = htmlspecialchars(trim($_POST['speaker_name']));
    $status = htmlspecialchars(trim($_POST['status']));
    $date = htmlspecialchars(trim($_POST['date']));
    $duration = htmlspecialchars(trim($_POST['duration']));
    $start_time = htmlspecialchars(trim($_POST['start_time']));

    // Handle image uploads
    $meeting_image = $_FILES['meeting_image']['name'];
    $speaker_image = $_FILES['speaker_image']['name'];

    // Set the upload directories for actual upload
    $upload_directory = '../meetings/'; // Directory for uploads
    $meeting_image_path = './meetings/' . basename($meeting_image); // Path to save in the database
    $speaker_image_path = './meetings/' . basename($speaker_image); // Path to save in the database

    // Move uploaded files
    if (move_uploaded_file($_FILES['meeting_image']['tmp_name'], $upload_directory . basename($meeting_image)) &&
        move_uploaded_file($_FILES['speaker_image']['tmp_name'], $upload_directory . basename($speaker_image))) {
        
        // Insert data into the database
        try {
            $stmt = $conn->prepare("INSERT INTO meetings (title, meeting_id, speaker_name, status, date, duration, start_time, meeting_image, speaker_image) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
            $stmt->execute([$title, $meeting_id, $speaker_name, $status, $date, $duration, $start_time, $meeting_image_path, $speaker_image_path]);

            $successMessage = 'Meeting saved successfully!';
        } catch (PDOException $e) {
            $errorMessage = 'Error: ' . $e->getMessage();
        }
    } else {
        $errorMessage = 'Error uploading images.';
    }
}

// Handle deletion of meetings
if (isset($_GET['delete'])) {
    $meetingId = $_GET['delete'];

    try {
        $stmt = $conn->prepare("DELETE FROM meetings WHERE id = ?");
        $stmt->execute([$meetingId]);

        $successMessage = 'Meeting deleted successfully!';
    } catch (PDOException $e) {
        $errorMessage = 'Error: ' . $e->getMessage();
    }
}

// Fetch all meetings for display
$stmt = $conn->prepare("SELECT * FROM meetings");
$stmt->execute();
$meetings = $stmt->fetchAll(PDO::FETCH_ASSOC);



// Send Notification to All Users
if (isset($_POST['send_notification'])) {
    $message = trim($_POST['message']);

    if (!empty($message)) {
        $stmt = $conn->prepare("INSERT INTO notifications (message, created_at, is_read) VALUES (:message, NOW(), 0)");
        $stmt->bindParam(':message', $message);
        
        if ($stmt->execute()) {
            $successMessage = "Notification sent successfully!";
        } else {
            $errorMessage = "Failed to send notification.";
        }
    } else {
        $errorMessage = "Notification message cannot be empty.";
    }
}

// Update Notification
if (isset($_POST['update_notification']) && !empty($_POST['notification_id'])) {
    $id = $_POST['notification_id'];
    $message = trim($_POST['message']);

    if (!empty($message)) {
        $stmt = $conn->prepare("UPDATE notifications SET message = :message WHERE id = :id");
        $stmt->bindParam(':message', $message);
        $stmt->bindParam(':id', $id);

        if ($stmt->execute()) {
            $successMessage = "Notification updated successfully!";
        } else {
            $errorMessage = "Failed to update notification.";
        }
    } else {
        $errorMessage = "Notification message cannot be empty.";
    }
}

// Edit Notification (Pre-fill the form)
if (isset($_GET['edit_notification'])) {
    $id = $_GET['edit_notification'];
    $stmt = $conn->prepare("SELECT * FROM notifications WHERE id = :id");
    $stmt->bindParam(':id', $id);
    $stmt->execute();
    $editNotification = $stmt->fetch(PDO::FETCH_ASSOC);
}

// Delete Notification
if (isset($_GET['delete_notification'])) {
    $id = $_GET['delete_notification'];
    $stmt = $conn->prepare("DELETE FROM notifications WHERE id = :id");
    $stmt->bindParam(':id', $id);

    if ($stmt->execute()) {
        $successMessage = "Notification deleted successfully!";
    } else {
        $errorMessage = "Failed to delete notification.";
    }
}


// Handle FAQ submission
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['submit_faq'])) {
    $question = trim($_POST['question']);
    $answer = trim($_POST['answer']);

    if (!empty($question) && !empty($answer)) {
        try {
            $stmt = $conn->prepare("INSERT INTO faqs (question, answer) VALUES (?, ?)");
            $stmt->execute([$question, $answer]);
            $success = "FAQ added successfully!";
        } catch (PDOException $e) {
            $error = "Error: " . $e->getMessage();
        }
    } else {
        $error = "All fields are required!";
    }
}

// Handle FAQ deletion
if (isset($_GET['delete'])) {
    $id = $_GET['delete'];
    try {
        $stmt = $conn->prepare("DELETE FROM faqs WHERE id = ?");
        $stmt->execute([$id]);
        $success = "FAQ deleted successfully!";
    } catch (PDOException $e) {
        $error = "Error: " . $e->getMessage();
    }
}

// Fetch all FAQs
try {
    $stmt = $conn->prepare("SELECT * FROM faqs ORDER BY created_at DESC");
    $stmt->execute();
    $faqs = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("Database error: " . $e->getMessage());
}


// Check if form is submitted
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_FILES['pdfFile'])) {
    // Retrieve form data
    $title = $_POST['title'];
    $pdfFile = $_FILES['pdfFile'];

    // Set file upload directory (admin upload path)
    $uploadDir = './documents/'; 

    // Ensure the file path is safe
    $filePath = $uploadDir . basename($pdfFile['name']);

    // Check if the uploaded file is a PDF
    $fileType = strtolower(pathinfo($filePath, PATHINFO_EXTENSION));
    if ($fileType != 'pdf') {
        $error = "Only PDF files are allowed!";
    } else {
        // Move uploaded file to the server's directory
        if (move_uploaded_file($pdfFile['tmp_name'], $filePath)) {
            // Insert file data into the database
            // Make sure you have a valid database connection ($conn) here
            $stmt = $conn->prepare("INSERT INTO documents (title, file_path) VALUES (?, ?)");
            if ($stmt->execute([$title, $filePath])) {
                $success = "PDF uploaded successfully!";
            } else {
                $error = "Failed to upload PDF to the database.";
            }
        } else {
            $error = "Failed to upload file.";
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin - Event Management Portal</title>

    <!-- DataTables CSS -->
    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.6/css/jquery.dataTables.min.css">
    <!-- DataTables Responsive CSS -->
    <link rel="stylesheet" href="https://cdn.datatables.net/responsive/2.5.0/css/responsive.dataTables.min.css">
    <!-- Bootstrap CSS -->
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="shortcut icon" href="../dist/img/icon2.png" type="image/x-icon">
    <link rel="stylesheet" href="../dist/css/custom.css">
    <link rel="stylesheet" href="../dist/css/mystyle.css">

    <!-- jQuery (necessary for Bootstrap's JavaScript plugins and DataTables) -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script> <!-- Full version of jQuery -->
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/responsive/2.5.0/js/dataTables.responsive.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.6/css/jquery.dataTables.min.css">

<script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>

</head>

    <style>
        .card-img-top {
            height: 150px;
            object-fit: cover;
        }
 
        /* Footer */
.main-footer {
    background: linear-gradient(180deg, #268fff, #007bff); ; /* Light mode background for footer */
    color: white;
}
    </style>
</head>
<body>
<div class="container mt-3">
    <h2>Manage Menu Items</h2>

    <!-- Form for Adding/Updating Menu Items -->
    <form action="admin.php" method="POST" enctype="multipart/form-data">
        <input type="hidden" name="id" value="<?php echo htmlspecialchars($editItem['id'] ?? ''); ?>">
        <input type="hidden" name="existing_image" value="<?php echo htmlspecialchars($editItem['image'] ?? ''); ?>">
        <div class="form-group">
            <label for="name">Name</label>
            <input type="text" class="form-control" id="name" name="name" value="<?php echo htmlspecialchars($editItem['name'] ?? ''); ?>" required>
        </div>
        <div class="form-group">
            <label for="icon">Icon</label>
            <input type="text" class="form-control" id="icon" name="icon" value="<?php echo htmlspecialchars($editItem['icon'] ?? ''); ?>" required>
        </div>
        <div class="form-group">
            <label for="link">Link</label>
            <input type="text" class="form-control" id="link" name="link" value="<?php echo htmlspecialchars($editItem['link'] ?? ''); ?>" required>
        </div>
        <div class="form-group">
            <label for="status">Status</label>
            <select class="form-control" id="status" name="status" required>
                <option value="active" <?php echo (isset($editItem['status']) && $editItem['status'] == 'active') ? 'selected' : ''; ?>>Active</option>
                <option value="inactive" <?php echo (isset($editItem['status']) && $editItem['status'] == 'inactive') ? 'selected' : ''; ?>>Inactive</option>
            </select>
        </div>
        <div class="form-group">
            <label for="image">Image</label>
            <input type="file" class="form-control-file" id="image" name="image">
            <?php if (!empty($editItem['image'])): ?>
                <img src=".<?php echo htmlspecialchars($editItem['image']); ?>" alt="Current Image" class="img-fluid mt-2" style="max-width: 100px;">
            <?php endif; ?>
        </div>
        <div class="form-group">
            <label for="link">Order</label>
            <input type="number" class="form-control" id="order" name="order" value="<?php echo htmlspecialchars($editItem['order'] ?? ''); ?>" required>
        </div>
        <button type="submit" class="btn btn-primary" name="submit_menu">Save Menu Item</button>
    </form>

    <!-- List Existing Menu Items with Delete Option -->
    <h3 class="mt-5">Existing Menu Items</h3>
    <table id="menuTable" class="table table-bordered dt-responsive nowrap" style="width: 100%;">
    <thead>
    <thead>
        <tr>
            <th>Name</th>
            <th>Icon</th>
            <th>Link</th>
            <th>Status</th>
            <th>Image</th>
            <th>Actions</th>
        </tr>
    </thead>
    <tbody>
        <?php foreach ($menuItems as $item): ?>
            <tr>
                <td><?php echo htmlspecialchars($item['name']); ?></td>
                <td><?php echo htmlspecialchars($item['icon']); ?></td>
                <td><?php echo htmlspecialchars($item['link']); ?></td>
                <td><?php echo htmlspecialchars($item['status']); ?></td>
                <td>
                    <?php if ($item['image']): ?>
                        <img src=".<?php echo htmlspecialchars($item['image']); ?>" alt="Image" class="img-fluid" style="max-width: 100px;">
                    <?php else: ?>
                        No Image
                    <?php endif; ?>
                </td>
                <td>
                    <a href="admin.php?edit=<?php echo htmlspecialchars($item['id']); ?>" class="btn btn-warning btn-sm">Edit</a>
                    <a href="admin.php?deletenav=<?php echo htmlspecialchars($item['id']); ?>" name="deletenav" class="btn btn-danger btn-sm">Delete</a>
                </td>
            </tr>
        <?php endforeach; ?>
    </tbody>
</table>



    <!-- Card for Reordering Navbar Items -->
    <div class="card mt-4">
        <div class="card-header">
            <h4>Reorder Navbar Items</h4>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Name</th>
                            <th>Order</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($menuItems as $item): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($item['name']); ?></td>
                                <td>
                                    <input type="number" name="order[<?php echo $item['id']; ?>]" value="<?php echo $item['order']; ?>" class="form-control" min="1" required>
                                </td>
                                <td>
                                    <a href="admin.php?deletenav=<?php echo $item['id']; ?>" class="btn btn-danger">Delete</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>

                <div class="mb-3">
                    <button type="submit" name="reorder_menu" class="btn btn-success">Update Order</button>
                </div>
            </form>
        </div>
    </div>
</div>


<script>
function editMenu(id, name, icon, link, status) {
    document.getElementById('menu-id').value = id;
    document.getElementById('name').value = name;
    document.getElementById('icon').value = icon;
    document.getElementById('link').value = link;
    document.getElementById('status').value = status;
}
</script>
<script>
$(document).ready(function() {
    $('#menuTable').DataTable({
        "paging": true,      // Enable pagination
        "searching": true,   // Enable searching
        "info": true,        // Show table information
        "ordering": true     // Enable column sorting
    });
});
</script>

<div class="container mt-5">
    <h2>Manage Cover Picture</h2>

    <?php if (isset($error)): ?>
        <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
    <?php endif; ?>

    <form action="admin.php" method="POST" enctype="multipart/form-data">
        <div class="form-group">
            <label for="cover_image">Upload Cover Image</label>
            <input type="file" name="cover_image" class="form-control-file" id="cover_image" required>
        </div>
        <button type="submit" class="btn btn-primary">Upload Image</button>
    </form>

    <hr>

    <h3>Current Cover Picture</h3>
    <?php if ($coverPic): ?>
        <img src="<?php echo htmlspecialchars($coverPic['image_path']); ?>" width="100px" alt="Cover Picture" class="img-fluid">
        <a href="admin.php?delete_cover" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this cover picture?')">Delete</a>
    <?php else: ?>
        <p>No cover picture set.</p>
    <?php endif; ?>
    
    <h3>Registration Analysis</h3>
    <form action="" method="post" enctype="multipart/form-data">
        <input type="hidden" name="action" value="add">
        <div class="form-group">
            <label for="description">Description:</label>
            <input type="text" class="form-control" id="description" name="description" required>
        </div>
        <div class="form-group">
            <label for="image">Image:</label>
            <input type="file" class="form-control-file" id="image" name="image">
        </div>
        <button type="submit" class="btn btn-primary">Submit</button>
    </form>

    <h3 class="mt-5">Registration Analysis Records</h3>
    <div class="row">
        <?php foreach ($analysisItems as $item): ?>
            <div class="col-xl-3 col-sm-6 col-12 mb-4">
                <div class="card bg-light">
                    <img src=".<?php echo htmlspecialchars($item['image']); ?>" class="card-img-top" alt="Image">
                    <div class="card-body">
                        <h5 class="card-title"><?php echo htmlspecialchars($item['description']); ?></h5>
                        <form action="" method="post" onsubmit="return confirm('Are you sure you want to delete this record?');">
                            <input type="hidden" name="action" value="delete">
                            <input type="hidden" name="id" value="<?php echo htmlspecialchars($item['id']); ?>">
                            <button type="submit" class="btn btn-danger">Delete</button>
                        </form>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>
</div>
<div class="container mt-3">
    <h3>Add Video</h3>
    <form action="" method="post">
        <div class="form-group">
            <label for="video_id">YouTube Video ID:</label>
            <input type="text" class="form-control" id="video_id" name="video_id" required>
        </div>
        <div class="form-group">
            <label for="title">Title:</label>
            <input type="text" class="form-control" id="title" name="title" required>
        </div>
        <div class="form-group">
            <label for="description">Description:</label>
            <textarea class="form-control" id="description" name="description" rows="4" required></textarea>
        </div>
        <div class="form-group">
            <label for="thumbnail">Thumbnail URL:</label>
            <input type="text" class="form-control" id="thumbnail" name="thumbnail" required>
        </div>
        <input type="hidden" name="add_video" value="1">
        <button type="submit" class="btn btn-primary">Add Video</button>
    </form>

    <h3 class="mt-5">Existing Videos</h3>
    <div class="row">
        <?php foreach ($videos as $video): ?>
            <div class="col-md-4 mb-4">
                <div class="video-card">
                    <div class="position-relative">
                        <img src="<?php echo htmlspecialchars($video['thumbnail']); ?>" class="img-fluid" alt="<?php echo htmlspecialchars($video['title']); ?>">
                        <button class="btn play-button" data-id="<?php echo htmlspecialchars($video['video_id']); ?>" data-title="<?php echo htmlspecialchars($video['title']); ?>">
                            <i class="fas fa-play"></i>
                        </button>
                    </div>
                    <div class="video-card-body">
                        <h5 class="video-card-title"><?php echo htmlspecialchars($video['title']); ?></h5>
                        <p class="video-card-text"><?php echo htmlspecialchars($video['description']); ?></p>
                        <form action="" method="post" class="mt-2">
                            <input type="hidden" name="video_id" value="<?php echo htmlspecialchars($video['video_id']); ?>">
                            <input type="hidden" name="delete_video" value="1">
                            <button type="submit" class="btn btn-danger">Delete</button>
                        </form>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>
</div>

<div class="container mt-4">
    <h3>Admin - Modal Content</h3>
    <form action="admin.php" method="post">
        <div class="form-group">
            <label for="message">Modal Message</label>
            <textarea id="message" name="message" class="form-control" rows="10" required><?php echo htmlspecialchars($currentMessage); ?></textarea>
        </div>
        <button type="submit" name="save" class="btn btn-primary">Save</button>
        <button type="submit" name="delete" class="btn btn-danger">Delete</button>
    </form>
</div><br><br><br><br>
 <!-- Footer -->
 <footer class="main-footer text-sm bg-light" style="padding: 5px 0; min-height: 50px;">
    <div class="container text-center" style="max-width: 800px; margin: 0 auto;">
        <div class="text-xs" id="copyright">
            <?php echo $copyrightMessage; ?>
            <div class="float-right d-none d-sm-inline-block">
                <b><?php echo $eventInfo; ?></b>
            </div>
        </div>
    </div>
</footer>


    <!-- Admin Section for Managing Footer -->
    <div class="container mt-4">
        <h3>Manage Footer</h3>
        <form action="" method="post">
            <input type="hidden" name="id" value="<?php echo htmlspecialchars($footer['id'] ?? ''); ?>">

            <div class="form-group">
                <label for="copyright_message">Copyright Message:</label>
                <textarea id="copyright_message" name="copyright_message" rows="3" class="form-control"><?php echo htmlspecialchars($copyrightMessage); ?></textarea>
            </div>

            <div class="form-group">
                <label for="event_info">Event Info:</label>
                <textarea id="event_info" name="event_info" rows="3" class="form-control"><?php echo htmlspecialchars($eventInfo); ?></textarea>
            </div>

            <button type="submit" name="update" class="btn btn-primary">Update Footer</button>
            <button type="submit" name="delete" class="btn btn-danger">Delete Footer</button>
        </form>
    </div>
<!--Adding New Products--->

<div class="container mt-3">
    <h3>Add New Product</h3>
    <form action="" method="post" enctype="multipart/form-data">
        <div class="form-group">
            <label for="name">Product Name:</label>
            <input type="text" class="form-control" id="name" name="name" required>
        </div>
        <div class="form-group">
            <label for="description">Description:</label>
            <textarea class="form-control" id="description" name="description" rows="4" required></textarea>
        </div>
        <div class="form-group">
            <label for="price">Price (₦):</label>
            <input type="number" class="form-control" id="price" name="price" step="0.01" required>
        </div>
        <div class="form-group">
            <label for="image">Product Image:</label>
            <input type="file" class="form-control-file" id="image" name="image" accept="image/*" required>
        </div>
        <input type="hidden" name="add_product" value="1">
        <button type="submit" class="btn btn-primary">Add Product</button>
    </form>
</div>


<!--Displaying Products--->
<div class="container mt-5">
    <h3 class="mt-5">Product Management</h3>
    <div class="row">
        <?php foreach ($products as $product): ?>
            <div class="col-xl-3 col-sm-6 col-12 mb-4">
                <div class="card bg-light">
                    <img src=".<?php echo htmlspecialchars($product['image_path']); ?>" class="card-img-top" alt="<?php echo htmlspecialchars($product['name']); ?>">
                    <div class="card-body">
                        <h5 class="card-title"><?php echo htmlspecialchars($product['name']); ?></h5>
                        <p class="card-text"><?php echo htmlspecialchars($product['description']); ?></p>
                        <p class="card-text">₦<?php echo htmlspecialchars(number_format($product['price'], 2)); ?></p>
                        <p class="card-text"><strong>Slug:</strong> <?php echo htmlspecialchars($product['slug']); ?></p> <!-- Display the slug here -->
                        <form action="" method="post" onsubmit="return confirm('Are you sure you want to delete this product?');">
                            <input type="hidden" name="action" value="delete">
                            <input type="hidden" name="id" value="<?php echo htmlspecialchars($product['id']); ?>">
                            <button type="submit" class="btn btn-danger">Delete</button>
                        </form>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>
</div>


<div class="container mt-5">
    <h3 class="mb-4">Database Table Manager</h3>
    
    <!-- Form to create new tables -->
    <div class="card mb-4">
        <div class="card-header">
            <h3 class="card-title">Create a New Table</h3>
        </div>
        <div class="card-body">
            <form action="create_table.php" method="post">
                <div class="form-group">
                    <label for="table_name">Table Name:</label>
                    <input type="text" id="table_name" name="table_name" class="form-control" required>
                </div>
                <div class="form-group">
                    <label for="columns">Columns (format: column_name:data_type, ...):</label>
                    <textarea id="columns" name="columns" class="form-control" rows="6" required></textarea>
                    <small class="form-text text-muted">
                        Example: <code>id:INT AUTO_INCREMENT PRIMARY KEY, name:VARCHAR(255), email:VARCHAR(255), created_at:DATETIME</code>
                    </small>
                </div>
                <button type="submit" class="btn btn-primary">Create Table</button>
            </form>
        </div>
    </div>
</div>



        <!-- Form to view and manage existing tables -->
        <div class="card">
            <div class="card-header">
                <h3 class="card-title">Manage Existing Tables</h3>
            </div>
            <div class="card-body">
                <form action="manage_tables.php" method="post">
                    <div class="form-group">
                        <label for="action">Choose Action:</label>
                        <select id="action" name="action" class="form-control">
                            <option value="view">View Tables</option>
                            <option value="drop">Drop Table</option>
                        </select>
                    </div>
                    <div class="form-group">
                        <label for="table_list">Select Table:</label>
                        <select id="table_list" name="table_list" class="form-control">
                           <option value="" selected disabled>Select Table to perform Action </option> 
                            <?php
                            // Include the database connection file
                            require_once("conn.php");

                            // Fetch existing tables
                            function getTableList() {
                                global $conn;
                                $tables = [];
                                try {
                                    $stmt = $conn->query("SHOW TABLES");
                                    while ($row = $stmt->fetch(PDO::FETCH_COLUMN)) {
                                        $tables[] = $row;
                                    }
                                } catch (PDOException $e) {
                                    echo "<script>alert('Error fetching tables: " . $e->getMessage() . "');</script>";
                                }
                                return $tables;
                            }

                            // Populate the <select> element with table names
                            $tables = getTableList();
                            foreach ($tables as $table) {
                                echo "<option value=\"$table\">$table</option>";
                            }
                            ?>
                        </select>
                    </div>
                    <button type="submit" class="btn btn-danger">Submit</button>
                </form>
            </div>
        </div>
    </div>

    <div class="container mt-5">
        <h3 class="mb-4">Database Setup</h3>
        <form action="create_conn.php" method="post">
            <div class="form-group">
                <label for="host">Database Host:</label>
                <input type="text" id="host" name="host" class="form-control" required>
            </div>
            <div class="form-group">
                <label for="dbname">Database Name:</label>
                <input type="text" id="dbname" name="dbname" class="form-control" required>
            </div>
            <div class="form-group">
                <label for="user">Username:</label>
                <input type="text" id="user" name="user" class="form-control" required>
            </div>
            <div class="form-group">
                <label for="pass">Password:</label>
                <input type="password" id="pass" name="pass" class="form-control" >
            </div>
            <button type="submit" class="btn btn-primary">Generate conn.php</button>
        </form>
    </div>

    <div class="container mt-5">
    <h3 class="mb-4">Create New Script File</h3>
    
    <div class="card">
        <div class="card-header">
            <h3 class="card-title">New Script File</h3>
        </div>
        <div class="card-body">
            <form action="create_script.php" method="post">
                <div class="form-group">
                    <label for="file_name">File Name:</label>
                    <input type="text" id="file_name" name="file_name" class="form-control" placeholder="Enter file name (e.g., new_script.php)" required>
                </div>
                <div class="form-group">
                    <label for="file_content">File Content:</label>
                    <textarea id="file_content" name="file_content" class="form-control" rows="10" placeholder="Enter PHP code here..." required></textarea>
                </div>
                <button type="submit" class="btn btn-primary">Create File</button>
            </form>
        </div>
    </div>
</div>

<div class="container mt-5">
<h3 class="mb-4">Manage Product Types</h3>

    <!-- Form to Add New Product Type -->
    <div class="card mb-4">
        <div class="card-header">
            Add New Product Type
        </div>
        <div class="card-body">
            <form action="admin.php" method="POST">
                <div class="form-group">
                    <label for="type">Type:</label>
                    <input type="text" id="type" name="type" class="form-control" required>
                </div>
                <button type="submit" name="add" class="btn btn-primary">Add Product Type</button>
            </form>
        </div>
    </div>
    
    <!-- List Product Types -->
    <div class="card">
        <div class="card-header">
            Product Types List
        </div>
        <div class="card-body">
            <table class="table table-bordered">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Type</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($productTypes as $productType): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($productType['id']); ?></td>
                            <td><?php echo htmlspecialchars($productType['type']); ?></td>
                            <td>
                                <a href="admin.php?edit=<?php echo $productType['id']; ?>" class="btn btn-warning btn-sm">Edit</a>
                                <a href="admin.php?delete=<?php echo $productType['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this item?');">Delete</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
    
    <?php if (isset($_GET['edit'])): ?>
        <?php
        // Fetch the product type to edit
        $id = intval($_GET['edit']);
        $stmt = $conn->prepare("SELECT * FROM product_types WHERE id = ?");
        $stmt->execute([$id]);
        $productType = $stmt->fetch(PDO::FETCH_ASSOC);
        ?>
        <div class="card mt-4">
            <div class="card-header">
                Edit Product Type
            </div>
            <div class="card-body">
                <form action="admin.php" method="POST">
                    <input type="hidden" name="id" value="<?php echo htmlspecialchars($productType['id']); ?>">
                    <div class="form-group">
                        <label for="edit_type">Type:</label>
                        <input type="text" id="edit_type" name="type" class="form-control" value="<?php echo htmlspecialchars($productType['type']); ?>" required>
                    </div>
                    <button type="submit" name="update" class="btn btn-success">Update Product Type</button>
                </form>
            </div>
        </div>
    <?php endif; ?>
</div>
<div class="container mt-5">
    <div class="card mb-4">
        <div class="card-header">
            Drop or Add Column
        </div>
        <div class="card-body">
            <!-- Form to Drop a Column -->
            <h4>Drop a Column</h4>
            <form action="manage_columns.php" method="POST" class="mb-4">
                <input type="hidden" name="action" value="drop">
                <div class="form-group">
                    <label for="table_name">Table Name:</label>
                    <input type="text" id="table_name" name="table_name" class="form-control" required>
                </div>
                <div class="form-group">
                    <label for="column_name">Column Name:</label>
                    <input type="text" id="column_name" name="column_name" class="form-control" required>
                </div>
                <button type="submit" class="btn btn-danger">Drop Column</button>
            </form>

            <!-- Form to Add a Column -->
            <h4>Add a Column</h4>
            <form action="manage_columns.php" method="POST">
                <input type="hidden" name="action" value="add">
                <div class="form-group">
                    <label for="table_name_add">Table Name:</label>
                    <input type="text" id="table_name_add" name="table_name" class="form-control" required>
                </div>
                <div class="form-group">
                    <label for="column_name_add">Column Name:</label>
                    <input type="text" id="column_name_add" name="column_name" class="form-control" required>
                </div>
                <div class="form-group">
                    <label for="column_type">Column Type:</label>
                    <input type="text" id="column_type" name="column_type" class="form-control" placeholder="e.g., VARCHAR(255), INT" required>
                </div>
                <div class="form-group">
                    <label for="position">Position:</label>
                    <select id="position" name="position" class="form-control">
                        <option value="FIRST">At the Beginning</option>
                        <option value="AFTER">After a Specific Column</option>
                    </select>
                </div>
                <div class="form-group" id="after_column_div" style="display: none;">
                    <label for="after_column">After Column:</label>
                    <input type="text" id="after_column" name="after_column" class="form-control" placeholder="Column name to place after">
                </div>
                <button type="submit" class="btn btn-primary">Add Column</button>
            </form>
        </div>
    </div>
</div>


<div class="container my-5">
    <h2 class="text-center mb-4">Manage Upcoming Events</h2>

    <!-- Event Form -->
    <form action="admin.php" method="POST" enctype="multipart/form-data">
        <input type="hidden" name="event_id" value="<?php echo isset($event['id']) ? $event['id'] : ''; ?>">

        <div class="mb-3">
            <label for="event_name" class="form-label">Event Name</label>
            <input type="text" class="form-control" id="event_name" name="event_name" required>
        </div>

        <div class="mb-3">
            <label for="event_details" class="form-label">Event Details</label>
            <textarea class="form-control" id="event_details" name="event_details" rows="4" required></textarea>
        </div>

        <div class="mb-3">
            <label for="event_date" class="form-label">Event Date</label>
            <input type="datetime-local" class="form-control" id="event_date" name="event_date" required>
        </div>

        <div class="mb-3">
        <label for="event_link" class="form-label">Event Link</label>
        <input type="url" class="form-control" id="event_link" name="event_link" placeholder="https://example.com" required>
        <div class="form-text">Enter the URL where users can get more information or register for the event.</div>
    </div>

        <div class="mb-3">
            <label for="button_text" class="form-label">Button Text</label>
            <input type="text" class="form-control" id="button_text" name="button_text" required>
        </div>

        <div class="mb-3 form-check">
            <input type="checkbox" class="form-check-input" id="button_active" name="button_active" <?php echo isset($event['button_active']) && $event['button_active'] == 1 ? 'checked' : ''; ?>>
            <label class="form-check-label" for="button_active">Button Active</label>
        </div>

        <div class="mb-3">
            <label for="event_image" class="form-label">Event Image</label>
            <input type="file" class="form-control" id="event_image" name="event_image">
        </div>

        <button type="submit" name="upcomingevent" class="btn btn-primary">Save Event</button>
    </form>


    <div class="container my-5">
    <h2 class="text-center mb-4">Manage Upcoming Events</h2>

    <!-- Event Form -->
    <form action="admin.php" method="POST" enctype="multipart/form-data">
        <input type="hidden" name="event_id" value="<?php echo isset($event['id']) ? $event['id'] : ''; ?>">

        <div class="mb-3">
            <label for="event_name" class="form-label">Event Name</label>
            <input type="text" class="form-control" id="event_name" name="event_name" value="<?php echo isset($event['event_name']) ? htmlspecialchars($event['event_name']) : ''; ?>" required>
        </div>

        <div class="mb-3">
            <label for="event_details" class="form-label">Event Details</label>
            <textarea class="form-control" id="event_details" name="event_details" rows="4" required><?php echo isset($event['event_details']) ? htmlspecialchars($event['event_details']) : ''; ?></textarea>
        </div>

        <div class="mb-3">
            <label for="event_date" class="form-label">Event Date</label>
            <input type="datetime-local" class="form-control" id="event_date" name="event_date" value="<?php echo isset($event['event_date']) ? date('Y-m-d\TH:i', strtotime($event['event_date'])) : ''; ?>" required>
        </div>

        <div class="mb-3">
            <label for="event_link" class="form-label">Event Link</label>
            <input type="url" class="form-control" id="event_link" name="event_link" value="<?php echo isset($event['event_link']) ? htmlspecialchars($event['event_link']) : ''; ?>" placeholder="https://example.com" required>
            <div class="form-text">Enter the URL where users can get more information or register for the event.</div>
        </div>

        <div class="mb-3">
            <label for="button_text" class="form-label">Button Text</label>
            <input type="text" class="form-control" id="button_text" name="button_text" value="<?php echo isset($event['button_text']) ? htmlspecialchars($event['button_text']) : ''; ?>" required>
        </div>

        <div class="mb-3 form-check">
            <input type="checkbox" class="form-check-input" id="button_active" name="button_active" <?php echo isset($event['button_active']) && $event['button_active'] == 1 ? 'checked' : ''; ?>>
            <label class="form-check-label" for="button_active">Button Active</label>
        </div>

        <div class="mb-3">
            <label for="event_image" class="form-label">Event Image</label>
            <input type="file" class="form-control" id="event_image" name="event_image">
        </div>

        <button type="submit" name="upcomingevent" class="btn btn-primary">Save Event</button>
    </form>
</div>

    <!-- Events List -->
    <div class="mt-5">
        <h4>Upcoming Events</h4>
        <table class="table table-bordered table-striped">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Name</th>
                    <th>Date</th>
                    <th>Link</th>
                    <th>Image</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($events as $event): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($event['id']); ?></td>
                        <td><?php echo htmlspecialchars($event['event_name']); ?></td>
                        <td><?php echo htmlspecialchars($event['event_date']); ?></td>
                        <td><a href="<?php echo htmlspecialchars($event['event_link']); ?>" target="_blank">View Link</a></td>
                        <td><img src="<?php echo '../' . htmlspecialchars($event['event_image']); ?>" alt="Event Image" style="max-width: 100px;"></td>
                        <td>
                            <a href="admin.php?editevent=<?php echo $event['id']; ?>" class="btn btn-warning btn-sm">Edit</a>
                            <a href="admin.php?deleteevent=<?php echo $event['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this event?');">Delete</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<div class="container my-5">
<h4>Edit Upcoming Events</h4>
<form action="admin.php" method="post" enctype="multipart/form-data">
    <input type="hidden" name="event_id" value="<?php echo $editEvent['id'] ?? ''; ?>">
    <div class="form-group">
        <label for="event_name">Event Name</label>
        <input type="text" class="form-control" id="event_name" name="event_name" value="<?php echo htmlspecialchars($editEvent['event_name'] ?? ''); ?>" required>
    </div>
    <div class="form-group">
        <label for="event_details">Event Details</label>
        <textarea class="form-control" id="event_details" name="event_details" required><?php echo htmlspecialchars($editEvent['event_details'] ?? ''); ?></textarea>
    </div>
    <div class="form-group">
        <label for="event_date">Event Date</label>
        <input type="datetime-local" class="form-control" id="event_date" name="event_date" value="<?php echo htmlspecialchars($editEvent['event_date'] ?? ''); ?>" required>
    </div>
    <div class="form-group">
        <label for="event_link">Event Link</label>
        <input type="url" class="form-control" id="event_link" name="event_link" value="<?php echo htmlspecialchars($editEvent['event_link'] ?? ''); ?>" required>
    </div>
    <div class="form-group">
        <label for="button_text">Button Text</label>
        <input type="text" class="form-control" id="button_text" name="button_text" value="<?php echo htmlspecialchars($editEvent['button_text'] ?? ''); ?>" required>
    </div>
    <div class="form-group">
        <input type="checkbox" id="button_active" name="button_active" <?php echo ($editEvent['button_active'] ?? 0) ? 'checked' : ''; ?>>
        <label for="button_active">Button Active</label>
    </div>
    <div class="form-group">
        <label for="event_image">Event Image</label>
        <input type="file" class="form-control" id="event_image" name="event_image">
        <?php if (!empty($editEvent['event_image'])): ?>
            <img src=".<?php echo htmlspecialchars($editEvent['event_image']); ?>" alt="Current Image" width="100">
        <?php endif; ?>
    </div>
    <button type="submit" class="btn btn-primary">Save</button>
</form>
        </div>
        </div>
        </div>
        <div class="container mt-5">
    <h2 class="text-center">Send Notification</h2>

    <div class="card">
        <div class="card-body">
        <?php if (isset($successMessage)): ?>
    <div class="alert alert-success alert-dismissible fade show" role="alert">
        <?php echo $successMessage; ?>
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
            <span aria-hidden="true">&times;</span>
        </button>
    </div>
<?php endif; ?>

<?php if (isset($errorMessage)): ?>
    <div class="alert alert-danger alert-dismissible fade show" role="alert">
        <?php echo $errorMessage; ?>
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
            <span aria-hidden="true">&times;</span>
        </button>
    </div>
<?php endif; ?>

<script>
    // Automatically dismiss alerts after 5 seconds
    setTimeout(function() {
        $('.alert').alert('close');
    }, 5000); // Time in milliseconds
</script>


            <form method="POST" action="admin.php">
                <div class="form-group">
                    <label for="region">Region</label>
                    <select class="form-control" id="region" name="region" required>
                        <option value="">Select Region</option>
                        <?php for ($i = 1; $i <= 51; $i++): ?>
                            <option value="<?php echo $i; ?>">Region <?php echo $i; ?></option>
                        <?php endfor; ?>
                    </select>
                </div>
                <div class="form-group">
                    <label for="province">Province</label>
                    <select class="form-control" id="province" name="province" required>
                        <option value="">Select Province</option>
                    </select>
                </div>
                <div class="form-group">
                    <label for="message">Notification Message</label>
                    <textarea class="form-control" id="message" name="message" rows="4" required></textarea>
                </div>
                <button type="submit" name="notification" class="btn btn-primary">Send Notification</button>
            </form>
        </div>
    </div>

    <div class="card mt-4">
    <div class="card-body">
        <h3 class="text-center">All Notifications</h3>
        <table id="notificationsTable" class="table table-bordered mt-3">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Message</th>
                    <th>Province</th>
                    <th>Created At</th>
                    <th>Status</th>
                </tr>
            </thead>
            <tbody>
                <?php
                // Fetch notifications for admin
                $stmt = $conn->prepare("SELECT n.id, n.message, n.province, n.created_at, n.is_read FROM notifications n");
                $stmt->execute();
                $notifications = $stmt->fetchAll(PDO::FETCH_ASSOC);

                foreach ($notifications as $notification): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($notification['id']); ?></td>
                        <td><?php echo htmlspecialchars($notification['message']); ?></td>
                        <td><?php echo htmlspecialchars($notification['province']); ?></td>
                        <td><?php echo date('jS M, Y', strtotime($notification['created_at'])); ?></td>
                        <td>
                            <?php if ($notification['is_read']): ?>
                                <span class="badge badge-success">Read</span>
                            <?php else: ?>
                                <span class="badge badge-danger">Unread</span>
                            <?php endif; ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>


<!----General Notification----->
<div class="container mt-5">
    <h2 class="text-center">Send Notification to All Users</h2>

    <div class="card">
        <div class="card-body">
            <?php if (isset($successMessage)): ?>
                <div class="alert alert-success alert-dismissible fade show" role="alert">
                    <?php echo $successMessage; ?>
                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
            <?php endif; ?>

            <?php if (isset($errorMessage)): ?>
                <div class="alert alert-danger alert-dismissible fade show" role="alert">
                    <?php echo $errorMessage; ?>
                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
            <?php endif; ?>

            <script>
                // Automatically dismiss alerts after 5 seconds
                setTimeout(function() {
                    $('.alert').alert('close');
                }, 5000);
            </script>

            <!-- Notification Form -->
            <form method="POST" action="admin.php">
                <input type="hidden" name="notification_id" value="<?php echo $editNotification['id'] ?? ''; ?>">

                <div class="form-group">
                    <label for="message">Notification Message</label>
                    <textarea class="form-control" id="message" name="message" rows="4" required><?php echo htmlspecialchars($editNotification['message'] ?? ''); ?></textarea>
                </div>

                <button type="submit" name="<?php echo isset($editNotification) ? 'update_notification' : 'send_notification'; ?>" class="btn btn-primary">
                    <?php echo isset($editNotification) ? 'Update Notification' : 'Send Notification'; ?>
                </button>
            </form>
        </div>
    </div>

    <!-- Display All Notifications -->
    <div class="card mt-4">
        <div class="card-body">
            <h3 class="text-center">All Notifications</h3>
            <table id="notificationsTable" class="table table-bordered mt-3">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Message</th>
                        <th>Created At</th>
                        <th>Status</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    // Fetch all notifications
                    $stmt = $conn->prepare("SELECT id, message, created_at, is_read FROM notifications");
                    $stmt->execute();
                    $notifications = $stmt->fetchAll(PDO::FETCH_ASSOC);

                    foreach ($notifications as $notification): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($notification['id']); ?></td>
                            <td><?php echo htmlspecialchars($notification['message']); ?></td>
                            <td><?php echo date('jS M, Y', strtotime($notification['created_at'])); ?></td>
                            <td>
                                <?php if ($notification['is_read']): ?>
                                    <span class="badge badge-success">Read</span>
                                <?php else: ?>
                                    <span class="badge badge-danger">Unread</span>
                                <?php endif; ?>
                            </td>
                            <td>
                                <a href="admin.php?edit_notification=<?php echo $notification['id']; ?>" class="btn btn-sm btn-warning">Edit</a>
                                <a href="admin.php?delete_notification=<?php echo $notification['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('Are you sure you want to delete this notification?');">Delete</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>


<div class="container mt-5">
    <h2 class="text-center">Manage Meetings</h2>

    <?php if (isset($successMessage)): ?>
        <div class="alert alert-success"><?php echo $successMessage; ?></div>
    <?php endif; ?>

    <div class="card mb-4">
        <div class="card-header">
            <h5 class="mb-0">Add / Edit Meeting</h5>
        </div>
        <div class="card-body">
            <form action="admin.php" method="POST" enctype="multipart/form-data">
                <input type="hidden" name="event_id" value="<?php echo isset($event['id']) ? $event['id'] : ''; ?>">

                <div class="mb-3">
                    <label for="title" class="form-label">Meeting Title</label>
                    <input type="text" class="form-control" id="title" name="title" required>
                </div>

                <div class="mb-3">
                    <label for="meeting_id" class="form-label">Meeting ID</label>
                    <input type="text" class="form-control" id="meeting_id" name="meeting_id" required>
                </div>

                <div class="mb-3">
                    <label for="speaker_name" class="form-label">Speaker Name</label>
                    <input type="text" class="form-control" id="speaker_name" name="speaker_name" required>
                </div>

                <div class="mb-3">
                    <label for="status" class="form-label">Status</label>
                    <select class="form-control" id="status" name="status" required>
                        <option value="active">Active</option>
                        <option value="inactive">Inactive</option>
                    </select>
                </div>

                <div class="mb-3">
                    <label for="date" class="form-label">Date</label>
                    <input type="date" class="form-control" id="date" name="date" required>
                </div>

                <div class="mb-3">
                    <label for="duration" class="form-label">Duration</label>
                    <input type="text" class="form-control" id="duration" name="duration" required>
                </div>

                <div class="mb-3">
                    <label for="start_time" class="form-label">Start Time</label>
                    <input type="time" class="form-control" id="start_time" name="start_time" required>
                </div>

                <div class="mb-3">
                    <label for="meeting_image" class="form-label">Meeting Image</label>
                    <input type="file" class="form-control" id="meeting_image" name="meeting_image" accept="image/*">
                </div>

                <div class="mb-3">
                    <label for="speaker_image" class="form-label">Speaker Image</label>
                    <input type="file" class="form-control" id="speaker_image" name="speaker_image" accept="image/*">
                </div>

                <button type="submit" name="meetings" class="btn btn-primary">Save Meeting</button>
            </form>
        </div>
    </div>

    <h3 class="mt-5">All Meetings</h3>
    <table class="table table-bordered mt-3">
        <thead>
            <tr>
                <th>ID</th>
                <th>Title</th>
                <th>Meeting ID</th>
                <th>Speaker</th>
                <th>Date</th>
                <th>Status</th>
                <th>Actions</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($meetings as $meeting): ?>
                <tr>
                    <td><?php echo htmlspecialchars($meeting['id']); ?></td>
                    <td><?php echo htmlspecialchars($meeting['title']); ?></td>
                    <td><?php echo htmlspecialchars($meeting['meeting_id']); ?></td>
                    <td><?php echo htmlspecialchars($meeting['speaker_name']); ?></td>
                    <td><?php echo htmlspecialchars($meeting['date']); ?></td>
                    <td><?php echo htmlspecialchars($meeting['status']); ?></td>
                    <td>
                        <a href="admin.php?edit=<?php echo $meeting['id']; ?>" class="btn btn-warning btn-sm">Edit</a>
                        <a href="admin.php?delete=<?php echo $meeting['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this meeting?');">Delete</a>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>

<div class="container mt-4">
    <h2 class="mb-3 text-success">Manage FAQs</h2>

    <!-- Display Success or Error Message -->
    <?php if (isset($success)): ?>
        <div class="alert alert-success"><?= $success; ?></div>
    <?php endif; ?>
    <?php if (isset($error)): ?>
        <div class="alert alert-danger"><?= $error; ?></div>
    <?php endif; ?>

    <div class="row">
        <!-- FAQ Upload Form -->
        <div class="col-md-5">
            <div class="card">
                <div class="card-header bg-success text-white">
                    <h5 class="mb-0"><i class="fas fa-plus-circle"></i> Add New FAQ</h5>
                </div>
                <div class="card-body">
                    <form method="POST" action="">
                        <div class="mb-3">
                            <label class="form-label">Question</label>
                            <input type="text" class="form-control" name="question" required>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Answer</label>
                            <textarea class="form-control" name="answer" rows="4" required></textarea>
                        </div>
                        <button type="submit" name="submit_faq" class="btn btn-success">
                            <i class="fas fa-upload"></i> Upload FAQ
                        </button>
                    </form>
                </div>
            </div>
        </div>

        <!-- FAQ List Table -->
        <div class="col-md-7">
            <div class="card">
                <div class="card-header bg-dark text-white">
                    <h5 class="mb-0"><i class="fas fa-list"></i> Existing FAQs</h5>
                </div>
                <div class="card-body">
                    <table class="table table-bordered">
                        <thead class="table-success">
                            <tr>
                                <th>#</th>
                                <th>Question</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($faqs)): ?>
                                <?php foreach ($faqs as $index => $faq): ?>
                                    <tr>
                                        <td><?= $index + 1; ?></td>
                                        <td><?= htmlspecialchars($faq['question']); ?></td>
                                        <td>
                                            <a href="?delete=<?= $faq['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('Are you sure?')">
                                                <i class="fas fa-trash"></i> Delete
                                            </a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr><td colspan="3" class="text-center">No FAQs found.</td></tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>

<div class="container mt-5">
    <h4>Upload PDF Document</h4>
    
    <!-- Display success or error messages -->
    <?php if (isset($success)): ?>
        <div class="alert alert-success"><?= $success ?></div>
    <?php elseif (isset($error)): ?>
        <div class="alert alert-danger"><?= $error ?></div>
    <?php endif; ?>

    <!-- Form to upload PDF -->
    <form method="POST" enctype="multipart/form-data">
        <div class="mb-3">
            <label for="title" class="form-label">Document Title</label>
            <input type="text" id="title" name="title" class="form-control" required>
        </div>
        
        <div class="mb-3">
            <label for="pdfFile" class="form-label">Choose PDF File</label>
            <input type="file" id="pdfFile" name="pdfFile" class="form-control" accept=".pdf" required>
        </div>
        
        <button type="submit" class="btn btn-primary">Upload</button>
    </form>
</div>

<script>
$(document).ready(function() {
    $('#notificationsTable').DataTable({
        "paging": true,
        "searching": true,
        "lengthChange": true,
        "pageLength": 10,
        "language": {
            "search": "Search Notifications:",
            "lengthMenu": "Show _MENU_ notifications per page"
        }
    });
});
</script>

<script>
$('#region').change(function() {
    let regionValue = $(this).val();
    console.log("Selected Region: ", regionValue); // Debugging line
    if (regionValue) {
        $.ajax({
            url: 'fetch_provinces.php',
            type: 'GET',
            data: { region: regionValue },
            dataType: 'json',
            success: function(data) {
                console.log("Provinces Data: ", data); // Debugging line
                $('#province').empty().append('<option value="">Select Province</option>');
                data.forEach(function(province) {
                    $('#province').append(`<option value="${province.province}">${province.province}</option>`);
                });
            },
            error: function() {
                alert('Error fetching provinces.');
            }
        });
    } else {
        $('#province').empty().append('<option value="">Select Province</option>');
    }
});
</script>


    
    </div></div>
      
        <script>
    document.getElementById('position').addEventListener('change', function() {
        var value = this.value;
        if (value === 'AFTER') {
            document.getElementById('after_column_div').style.display = 'block';
        } else {
            document.getElementById('after_column_div').style.display = 'none';
        }
    });
</script>
<!-- Font Awesome for icons -->
<script src="https://kit.fontawesome.com/a076d05399.js"></script>
<!-- DataTables JS -->
<!-- <script src="https://code.jquery.com/jquery-3.6.4.min.js"></script> -->
<script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>

<!-- DataTables Responsive JS -->
<script src="https://cdn.datatables.net/responsive/2.5.0/js/dataTables.responsive.min.js"></script>

</body>
</html>
