<?php
include 'connection.php'; // This file must create the PDO connection in $conn

if (!isset($_GET['id'])) {
    die("No coordinator specified.");
}

$id = intval($_GET['id']);

// Fetch current coordinator details
$stmt = $conn->prepare("SELECT * FROM report_coordinators WHERE user_id = :id");
$stmt->bindParam(':id', $id, PDO::PARAM_INT);
$stmt->execute();
$coordinator = $stmt->fetch(PDO::FETCH_ASSOC);
if (!$coordinator) {
    die("Coordinator not found.");
}

// Split email to get the username portion (assuming email format: username@rccgjuniorchurch.org)
$emailParts = explode('@', $coordinator['email_address']);
$email_username = $emailParts[0];

// Process form submission for update
if ($_SERVER['REQUEST_METHOD'] === 'POST') {

    // Collect form inputs
    $email_prefix = trim($_POST['email_username'] ?? '');
    $email_address = $email_prefix . "@rccgjuniorchurch.org";
    $phone_number  = trim($_POST['phone_number'] ?? '');
    $full_name     = trim($_POST['full_name'] ?? '');
    $gender        = trim($_POST['gender'] ?? '');
    $zone          = trim($_POST['zone'] ?? '');
    $region        = trim($_POST['region'] ?? '');
    $province      = trim($_POST['province'] ?? '');
    $position      = trim($_POST['position'] ?? '');

    // Update query (password and other defaults remain unchanged)
    try {
        $stmt = $conn->prepare("UPDATE report_coordinators 
            SET email_address = :email_address, phone_number = :phone_number, full_name = :full_name, 
                gender = :gender, zone = :zone, region = :region, province = :province, position = :position 
            WHERE user_id = :id");
        $stmt->bindParam(':email_address', $email_address);
        $stmt->bindParam(':phone_number', $phone_number);
        $stmt->bindParam(':full_name', $full_name);
        $stmt->bindParam(':gender', $gender);
        $stmt->bindParam(':zone', $zone);
        $stmt->bindParam(':region', $region);
        $stmt->bindParam(':province', $province);
        $stmt->bindParam(':position', $position);
        $stmt->bindParam(':id', $id, PDO::PARAM_INT);
        if ($stmt->execute()) {
            $successMsg = "Coordinator updated successfully.";
            // Refresh data from database
            $stmt = $conn->prepare("SELECT * FROM report_coordinators WHERE user_id = :id");
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute();
            $coordinator = $stmt->fetch(PDO::FETCH_ASSOC);
            $emailParts = explode('@', $coordinator['email_address']);
            $email_username = $emailParts[0];
        } else {
            $errorMsg = "Error updating coordinator.";
        }
    } catch (PDOException $e) {
        $errorMsg = "Error: " . $e->getMessage();
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Edit Coordinator</title>
    <!-- Bootstrap 5 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- jQuery CDN (for AJAX and DOM manipulations) -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
</head>
<body class="bg-light">
<div class="container mt-5">
    <!-- Back Button -->
    <a href="zonalcoord.php" class="btn btn-secondary mb-3">&laquo; Back to Zonal Coordinators</a>

    <?php if (!empty($successMsg)): ?>
        <div class="alert alert-success alert-dismissible fade show" role="alert">
            <?= $successMsg ?>
            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
        </div>
    <?php endif; ?>
    <?php if (!empty($errorMsg)): ?>
        <div class="alert alert-danger alert-dismissible fade show" role="alert">
            <?= $errorMsg ?>
            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
        </div>
    <?php endif; ?>

    <div class="card shadow-sm">
        <div class="card-header bg-primary text-white">
            <h4 class="mb-0">Edit Coordinator</h4>
        </div>
        <div class="card-body">
            <form method="post" action="">
                <!-- Email Username -->
                <div class="mb-3">
                    <label for="email_username" class="form-label">Email Username</label>
                    <input type="text" class="form-control" id="email_username" name="email_username" placeholder="e.g., tolu" required value="<?= htmlspecialchars($email_username) ?>">
                    <small class="text-muted">
                        Your full email will be: <strong class="text-success" id="emailPreview"><?= htmlspecialchars($email_username) ?>@rccgjuniorchurch.org</strong>
                    </small>
                </div>

                <!-- Phone Number -->
                <div class="mb-3">
                    <label for="phone_number" class="form-label">Phone Number</label>
                    <input type="text" class="form-control" id="phone_number" name="phone_number" required value="<?= htmlspecialchars($coordinator['phone_number']) ?>">
                </div>

                <!-- Full Name -->
                <div class="mb-3">
                    <label for="full_name" class="form-label">Full Name</label>
                    <input type="text" class="form-control" id="full_name" name="full_name" required value="<?= htmlspecialchars($coordinator['full_name']) ?>">
                </div>

                <!-- Gender -->
                <div class="mb-3">
                    <label for="gender" class="form-label">Gender</label>
                    <select class="form-select" id="gender" name="gender" required>
                        <option value="">--Select Gender--</option>
                        <option value="Male" <?= ($coordinator['gender'] == 'Male') ? 'selected' : '' ?>>Male</option>
                        <option value="Female" <?= ($coordinator['gender'] == 'Female') ? 'selected' : '' ?>>Female</option>
                        <option value="Other" <?= ($coordinator['gender'] == 'Other') ? 'selected' : '' ?>>Other</option>
                    </select>
                </div>

                <!-- Zone -->
                <div class="mb-3">
                    <label for="zone" class="form-label">Zone</label>
                    <select class="form-select" id="zone" name="zone" required>
                        <option value="">--Select Zone--</option>
                        <option value="Zone 1 – Lagos Regions" <?= ($coordinator['zone'] == 'Zone 1 – Lagos Regions') ? 'selected' : '' ?>>Zone 1 – Lagos Regions</option>
                        <option value="Zone 2 – Western Regions" <?= ($coordinator['zone'] == 'Zone 2 – Western Regions') ? 'selected' : '' ?>>Zone 2 – Western Regions</option>
                        <option value="Zone 3 – South – South Regions" <?= ($coordinator['zone'] == 'Zone 3 – South – South Regions') ? 'selected' : '' ?>>Zone 3 – South – South Regions</option>
                        <option value="Zone 4 – Eastern Regions" <?= ($coordinator['zone'] == 'Zone 4 – Eastern Regions') ? 'selected' : '' ?>>Zone 4 – Eastern Regions</option>
                        <option value="Zone 5 – Northern Regions" <?= ($coordinator['zone'] == 'Zone 5 – Northern Regions') ? 'selected' : '' ?>>Zone 5 – Northern Regions</option>
                        <option value="Zone 6 – Northern Regions" <?= ($coordinator['zone'] == 'Zone 6 – Northern Regions') ? 'selected' : '' ?>>Zone 6 – Northern Regions</option>
                    </select>
                </div>

                <!-- Region -->
                <div class="mb-3">
                    <label for="region" class="form-label">Region</label>
                    <select class="form-select" id="region" name="region" required>
                        <option value="">--Select Region--</option>
                        <?php for ($i = 1; $i <= 69; $i++): ?>
                            <option value="<?= $i ?>" <?= ($coordinator['region'] == $i) ? 'selected' : '' ?>><?= $i ?></option>
                        <?php endfor; ?>
                    </select>
                </div>

                <!-- Province (populated via AJAX) -->
                <div class="mb-3">
                    <label for="province" class="form-label">Province</label>
                    <select class="form-select" id="province" name="province" required>
                        <option value="">--Select Province--</option>
                    </select>
                </div>

                <!-- Position -->
                <div class="mb-3">
                    <label for="position" class="form-label">Position</label>
                    <input type="text" class="form-control" id="position" name="position" required value="<?= htmlspecialchars($coordinator['position']) ?>">
                </div>

                <div class="d-grid">
                    <button type="submit" class="btn btn-primary">Update Coordinator</button>
                </div>
            </form>
        </div>
    </div>

    <!-- jQuery and AJAX Scripts -->
    <script>
        $(document).ready(function(){
            // Update email preview when the username field changes.
            $('#email_username').on('input', function(){
                var username = $(this).val().trim();
                var preview = username ? username + "@rccgjuniorchurch.org" : "[username]@rccgjuniorchurch.org";
                $('#emailPreview').text(preview);
            });

            // Auto-update Position field based on Zone selection.
            $('#zone').on('change', function(){
                var zoneVal = $(this).val();
                if(zoneVal) {
                    $('#position').val(zoneVal + " Coordinator");
                } else {
                    $('#position').val("");
                }
            });

            // AJAX to load provinces based on Region selection.
            $('#region').change(function(){
                var regionId = $(this).val();
                if(regionId) {
                    $.ajax({
                        url: 'get_provinces.php',
                        type: 'POST',
                        data: {region: regionId},
                        success: function(response){
                            $('#province').html(response);
                            // If the saved province is in the options, select it
                            <?php if(!empty($coordinator['province'])): ?>
                            $('#province').val("<?= htmlspecialchars($coordinator['province']) ?>");
                            <?php endif; ?>
                        },
                        error: function(){
                            $('#province').html('<option value="">Error loading provinces</option>');
                        }
                    });
                } else {
                    $('#province').html('<option value="">--Select Province--</option>');
                }
            });

            // Trigger change on region on page load to populate province dropdown.
            $('#region').trigger('change');
        });
    </script>

    <!-- Bootstrap 5 JS Bundle (includes Popper) -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
