<?php
include 'connection.php'; // This file must create the PDO connection in $conn

$actionMsg = "";

// Process GET actions for delete/disable/enable
if (isset($_GET['action'], $_GET['id'])) {
    $id = intval($_GET['id']);

    if ($_GET['action'] == 'delete') {
        $stmt = $conn->prepare("DELETE FROM report_coordinators WHERE user_id = :id");
        $stmt->bindParam(':id', $id, PDO::PARAM_INT);
        if ($stmt->execute()) {
            $actionMsg = "Coordinator deleted successfully.";
        } else {
            $actionMsg = "Error deleting coordinator.";
        }
    } elseif ($_GET['action'] == 'disable') {
        $stmt = $conn->prepare("UPDATE report_coordinators SET status = 'disabled' WHERE user_id = :id");
        $stmt->bindParam(':id', $id, PDO::PARAM_INT);
        if ($stmt->execute()) {
            $actionMsg = "Coordinator disabled successfully.";
        } else {
            $actionMsg = "Error disabling coordinator.";
        }
    } elseif ($_GET['action'] == 'enable') {
        $stmt = $conn->prepare("UPDATE report_coordinators SET status = 'active' WHERE user_id = :id");
        $stmt->bindParam(':id', $id, PDO::PARAM_INT);
        if ($stmt->execute()) {
            $actionMsg = "Coordinator enabled successfully.";
        } else {
            $actionMsg = "Error enabling coordinator.";
        }
    }
}

// Process form submission to add a new coordinator
if ($_SERVER['REQUEST_METHOD'] === 'POST') {

    // Collect form inputs
    $email_prefix = trim($_POST['email_username'] ?? '');
    $email_address = $email_prefix . "@rccgjuniorchurch.org";

    $phone_number  = trim($_POST['phone_number'] ?? '');
    $full_name     = trim($_POST['full_name'] ?? '');
    $gender        = trim($_POST['gender'] ?? '');
    $zone          = trim($_POST['zone'] ?? '');
    $region        = trim($_POST['region'] ?? '');
    $province      = trim($_POST['province'] ?? '');
    $position      = trim($_POST['position'] ?? '');

    // Convert encoding to UTF-8 to fix special characters
    $zone = mb_convert_encoding($zone, 'UTF-8', 'auto');

    // Default values for additional fields
    $continent    = 'Africa';
    $country      = 'Nigeria';
    $passport     = './assets/images/profile_pics/180x180.png';
    $coverPicture = './assets/images/cover_pictures/coverpic.png';

    // Function to generate a random string of given length
    function generateRandomString($length = 6) {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[random_int(0, strlen($characters) - 1)];
        }
        return $randomString;
    }

    // Generate password with fixed prefix "dtce" followed by 6 random characters
    $password = 'dtce' . generateRandomString(6);

    // Insert data into the database using PDO
    try {
        $stmt = $conn->prepare("
            INSERT INTO report_coordinators 
            (email_address, phone_number, full_name, password, gender, continent, zone, country, region, province, position, passport, coverPicture, status)
            VALUES 
            (:email_address, :phone_number, :full_name, :password, :gender, :continent, :zone, :country, :region, :province, :position, :passport, :coverPicture, 'active')
        ");

        // Bind parameters
        $stmt->bindParam(':email_address', $email_address);
        $stmt->bindParam(':phone_number',  $phone_number);
        $stmt->bindParam(':full_name',     $full_name);
        $stmt->bindParam(':password',      $password);
        $stmt->bindParam(':gender',        $gender);
        $stmt->bindParam(':continent',     $continent);
        $stmt->bindParam(':zone',          $zone); // Zone encoding fixed here
        $stmt->bindParam(':country',       $country);
        $stmt->bindParam(':region',        $region);
        $stmt->bindParam(':province',      $province);
        $stmt->bindParam(':position',      $position);
        $stmt->bindParam(':passport',      $passport);
        $stmt->bindParam(':coverPicture',  $coverPicture);

        // Execute the query
        $stmt->execute();

        $successMsg = "Coordinator added successfully!<br>Generated Password: <strong>$password</strong><br>Dedicated Email: <strong>$email_address</strong>";
    } catch (PDOException $e) {
        $errorMsg = "Error: " . $e->getMessage();
    }
}

// Fetch all coordinators for the management table
$stmt = $conn->prepare("SELECT * FROM report_coordinators ORDER BY user_id DESC");
$stmt->execute();
$coordinators = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Admin: Add & Manage Zonal Coordinators</title>
    <!-- Bootstrap 5 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- jQuery CDN (for AJAX and DOM manipulations) -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
</head>
<body class="bg-light">
    <div class="container mt-5">

        <!-- Display any action messages from GET actions -->
        <?php if (!empty($actionMsg)): ?>
            <div class="alert alert-info alert-dismissible fade show" role="alert">
                <?= $actionMsg ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <!-- Display success/error message for add form submission -->
        <?php if (!empty($successMsg)) : ?>
            <div class="alert alert-success alert-dismissible fade show" role="alert">
                <?= $successMsg ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php elseif (!empty($errorMsg)) : ?>
            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                <?= $errorMsg ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        <?php endif; ?>

        <!-- Add Coordinator Form -->
        <div class="card shadow-sm mb-5">
            <div class="card-header bg-primary text-white">
                <h4 class="mb-0">Add Zonal Coordinator</h4>
            </div>
            <div class="card-body">
                <form method="post" action="">
                    <!-- Email Username (the system will add @rccgjuniorchurch.org automatically) -->
                    <div class="mb-3">
                        <label for="email_username" class="form-label">Email Username</label>
                        <input type="text" class="form-control" id="email_username" name="email_username" placeholder="e.g., tolu" required>
                        <small class="text-muted">
                            Your full email will be: <strong class="text-success" id="emailPreview">[username]@rccgjuniorchurch.org</strong>
                        </small>
                    </div>

                    <!-- Phone Number -->
                    <div class="mb-3">
                        <label for="phone_number" class="form-label">Phone Number</label>
                        <input type="text" class="form-control" id="phone_number" name="phone_number" required>
                    </div>

                    <!-- Full Name -->
                    <div class="mb-3">
                        <label for="full_name" class="form-label">Full Name</label>
                        <input type="text" class="form-control" id="full_name" name="full_name" required>
                    </div>

                    <!-- Gender -->
                    <div class="mb-3">
                        <label for="gender" class="form-label">Gender</label>
                        <select class="form-select" id="gender" name="gender" required>
                            <option value="">--Select Gender--</option>
                            <option value="Male">Male</option>
                            <option value="Female">Female</option>
                            <option value="Other">Other</option>
                        </select>
                    </div>

                    <!-- Zone -->
                    <div class="mb-3">
        <label for="zone" class="form-label">Zone</label>
        <select class="form-select" id="zone" name="zone" required>
            <option value="">--Select Zone--</option>
            <option value="Zone 1 – Lagos Regions">Zone 1 – Lagos Regions</option>
            <option value="Zone 2 – Western Regions">Zone 2 – Western Regions</option>
            <option value="Zone 3 – South – South Regions">Zone 3 – South – South Regions</option>
            <option value="Zone 4 – Eastern Regions">Zone 4 – Eastern Regions</option>
            <option value="Zone 5 – Northern Regions">Zone 5 – Northern Regions</option>
            <option value="Zone 6 – Northern Regions">Zone 6 – Northern Regions</option>
        </select>
    </div>

                    <!-- Region -->
                    <div class="mb-3">
                        <label for="region" class="form-label">Region</label>
                        <select class="form-select" id="region" name="region" required>
                            <option value="">--Select Region--</option>
                            <?php for ($i = 1; $i <= 69; $i++): ?>
                                <option value="<?= $i ?>"><?= $i ?></option>
                            <?php endfor; ?>
                        </select>
                    </div>

                    <!-- Province (populated via AJAX) -->
                    <div class="mb-3">
                        <label for="province" class="form-label">Province</label>
                        <select class="form-select" id="province" name="province" required>
                            <option value="">--Select Province--</option>
                        </select>
                    </div>

                    <!-- Position -->
                    <div class="mb-3">
                        <label for="position" class="form-label">Position</label>
                        <input type="text" class="form-control" id="position" name="position" required>
                    </div>

                    <!-- Note: Password, Continent, Country, Passport, and Cover Picture are set automatically -->
                    <div class="d-grid">
                        <button type="submit" class="btn btn-primary">Add Coordinator</button>
                    </div>
                </form>
            </div>
        </div>

        <!-- Manage Coordinators Table -->
        <div class="card">
            <div class="card-header">
                <h4>Manage Zonal Coordinators</h4>
            </div>
            <div class="card-body">
                <table class="table table-bordered table-striped">
                    <thead>
                        <tr>
                            <th>User ID</th>
                            <th>Full Name</th>
                            <th>Email</th>
                            <th>Phone</th>
                            <th>Zone</th>
                            <th>Region</th>
                            <th>Province</th>
                            <th>Status</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($coordinators as $coord): ?>
                            <tr>
                                <td><?= htmlspecialchars($coord['user_id']) ?></td>
                                <td><?= htmlspecialchars($coord['full_name']) ?></td>
                                <td><?= htmlspecialchars($coord['email_address']) ?></td>
                                <td><?= htmlspecialchars($coord['phone_number']) ?></td>
                                <td><?= htmlspecialchars($coord['zone']) ?></td>
                                <td><?= htmlspecialchars($coord['region']) ?></td>
                                <td><?= htmlspecialchars($coord['province']) ?></td>
                                <td><?= htmlspecialchars($coord['status'] ?? 'active') ?></td>
                                <td>
                                    <a href="edit_coordinator.php?id=<?= $coord['user_id'] ?>" class="btn btn-sm btn-warning">Edit</a>
                                    <a href="?action=delete&id=<?= $coord['user_id'] ?>" onclick="return confirm('Are you sure you want to delete this coordinator?');" class="btn btn-sm btn-danger">Delete</a>
                                    <?php if (($coord['status'] ?? 'active') == 'active'): ?>
                                        <a href="?action=disable&id=<?= $coord['user_id'] ?>" onclick="return confirm('Disable this coordinator?');" class="btn btn-sm btn-secondary">Disable</a>
                                    <?php else: ?>
                                        <a href="?action=enable&id=<?= $coord['user_id'] ?>" onclick="return confirm('Enable this coordinator?');" class="btn btn-sm btn-success">Enable</a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>

    </div>

    <!-- jQuery and AJAX Scripts -->
    <script>
        $(document).ready(function(){
            // Update email preview when the username field changes.
            $('#email_username').on('input', function(){
                var username = $(this).val().trim();
                var preview = username ? username + "@rccgjuniorchurch.org" : "[username]@rccgjuniorchurch.org";
                $('#emailPreview').text(preview);
            });

            // Auto-update Position field based on Zone selection.
            $('#zone').on('change', function(){
                var zoneVal = $(this).val();
                if(zoneVal) {
                    $('#position').val(zoneVal + " Coordinator");
                } else {
                    $('#position').val("");
                }
            });

            // AJAX to load provinces based on Region selection.
            $('#region').change(function(){
                var regionId = $(this).val();
                if(regionId) {
                    $.ajax({
                        url: 'get_provinces.php',
                        type: 'POST',
                        data: {region: regionId},
                        success: function(response){
                            $('#province').html(response);
                        },
                        error: function(){
                            $('#province').html('<option value="">Error loading provinces</option>');
                        }
                    });
                } else {
                    $('#province').html('<option value="">--Select Province--</option>');
                }
            });
        });
    </script>

    <!-- Bootstrap 5 JS Bundle (includes Popper) -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
