<?php
require_once("conn.php");
session_start();

// Function to generate random password
function generate_password($length = 10) {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    return substr(str_shuffle($characters), 0, $length);
}

// Function to generate random Agent ID
function generate_agent_id($length = 4) {
    return 'DTCE' . strtoupper(substr(str_shuffle('0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'), 0, $length));
}

// Set agent ID in session
if (!isset($_SESSION['agent_id'])) {
    $_SESSION['agent_id'] = generate_agent_id();
}

// Handle form submission
$message = "";
if (isset($_POST['register'])) {
    $name = strtoupper(trim($_POST['name']));
    $idnumber = $_SESSION['agent_id'];
    $password = generate_password();

    if (!empty($name)) {
        // Check if agent already exists
        $stmt = $conn->prepare("SELECT * FROM regdepartment WHERE name = ?");
        $stmt->execute([$name]);

        if ($stmt->rowCount() > 0) {
            $message = "<div class='alert alert-danger'>Agent already exists!</div>";
        } else {
            // Insert new agent
            $stmt = $conn->prepare("INSERT INTO regdepartment (name, idnumber, password) VALUES (?, ?, ?)");
            if ($stmt->execute([$name, $idnumber, $password])) {
                $message = "<div class='alert alert-success'>Agent registered successfully! Your password is: <strong>$password</strong></div>";
                unset($_SESSION['agent_id']); // Reset agent ID for next registration
            } else {
                $message = "<div class='alert alert-danger'>Error: Could not register agent.</div>";
            }
        }
    } else {
        $message = "<div class='alert alert-warning'>Please enter a valid name.</div>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Agent Profile - Payment & Registration</title>
    <link rel="shortcut icon" type="image/x-icon" href="images/icon2.png">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">
    <style>
        body {
            background: linear-gradient(to right, #2c3e50, #4ca1af);
            color: #333;
            font-family: Arial, sans-serif;
            height: 100vh;
            display: flex;
            justify-content: center;
            align-items: center;
        }
        .card {
            width: 400px;
            background: #fff;
            padding: 30px;
            border-radius: 10px;
            box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.2);
        }
        .btn-custom {
            background-color: #186F45;
            color: white;
            font-weight: bold;
        }
        .btn-custom:hover {
            background-color: #145A32;
        }
        .form-control {
            border: 1px solid #186F45;
        }
        .alert {
            font-weight: bold;
            text-align: center;
        }
        .footer-text {
            font-size: 14px;
            text-align: center;
            margin-top: 10px;
            color: #555;
        }
    </style>
</head>
<body>

<div class="card text-center">
    <!-- <a href="../index.html" class="btn btn-light btn-sm float-end"><i class="fa fa-home"></i> Home</a> -->
    <h4 class="mt-3">Payment & Registration Agent Profile</h4>
    <img src="images/dtce.png" alt="DTCE LOGO" width="80px" class="mt-2 mb-3 center">

    <?= $message; ?>

    <form action="" method="post">
        <div class="mb-3">
            <label class="form-label"><i class="fa fa-id-card"></i> Agent ID Number</label>
            <input type="text" class="form-control text-center" value="<?= $_SESSION['agent_id']; ?>" readonly>
        </div>

        <div class="mb-3">
            <label class="form-label"><i class="fa fa-user"></i> Agent's Full Name</label>
            <input type="text" class="form-control" placeholder="Enter Agent's Full Name" name="name" required>
        </div>

        <button type="submit" class="btn btn-custom w-100" name="register"><i class="fa fa-user-plus"></i> Register Agent</button>
    </form>

    <div class="footer-text">
        <a href="./dashboard/index.php">Login as an Agent</a> |
        <a href="#" data-bs-toggle="tooltip" title="For help, contact ICT Help Desk.">Need Help?</a>
    </div>

    <div class="footer">
    &copy; <?php echo date("Y"); ?> PAYMENT AND REGISTRATION AGENT LOGIN. <br>
    <strong>Designed by Hi-Dev Solutions</strong>
</div>
</div>
<!-- Footer -->


<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
    var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'));
    var tooltipList = tooltipTriggerList.map(function (tooltipTriggerEl) {
        return new bootstrap.Tooltip(tooltipTriggerEl);
    });
</script>
</body>
</html>
