<?php

require_once("../session.php");

if (!isset($_SESSION['dashboard'])) {
    echo "<script>alert('Please Kindly Login to gain control...'); location.href='../index.php';</script>";
    exit;
}

include("../conn.php");
$agent_id = $_SESSION['dashboard'];
$agent_name = $_SESSION['name'];
$f_region = $_POST['region'] ?? '';
$selected_year = $_POST['year'] ?? date('Y');
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <title>Payment Approval Dashboard</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.4/css/dataTables.bootstrap5.min.css">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.4/js/dataTables.bootstrap5.min.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">
    <link rel="shortcut icon" type="image/x-icon" href="../images/icon2.png">
</head>

<body>
<div class="container mt-4">
    <div class="d-flex flex-wrap justify-content-between align-items-center mb-4 gap-2">
        <h2 class="text-primary">Payment Approval Dashboard (<?php echo date('Y'); ?>)</h2>
    </div>

    <div class="d-flex flex-wrap justify-content-center gap-3 mb-5">  <!-- Added mb-5 for more space -->
        <!-- Dark Mode Toggle -->
        <button id="themeToggle" class="btn btn-secondary">
            🌙 Dark Mode
        </button>

        <!-- Zone / Province Creation Button -->
        <a href="./zone.php" class="btn btn-info">
            <i class="bi bi-geo-alt-fill"></i> Zone / Province Creation
        </a>

        <!-- Send Notification Button -->
        <a href="./notification.php" class="btn btn-success">
            <i class="bi bi-bell-fill"></i> Send Notification
        </a>

        <!-- Payment Records Button -->
        <a href="./index.php" class="btn btn-warning">
            <i class="bi bi-cash-stack"></i> Payment Records
        </a>

        <!-- Logout Button -->
        <a href="../logout.php" class="btn btn-danger">
            <i class="bi bi-box-arrow-right"></i> Logout
        </a>
    </div>

    <!-- Increased space before the next card -->
    <div class="card p-3 mb-3">
        <h5 class="mb-2">Agent Details</h5>
        <p><strong>ID:</strong> <?php echo $agent_id; ?></p>
        <p><strong>Name:</strong> <?php echo $agent_name; ?></p>
    </div>



        <form method="POST" id="filterForm">
            <div class="card p-3 mb-3">
                <div class="row g-3">
                    <div class="col-md-4">
                        <label for="region" class="form-label">Select Region</label>
                        <select class="form-select" name="region" id="region" required>
                            <option value="" disabled selected>Choose Region</option>
                            <?php for ($i = 1; $i <= 51; $i++) { ?>
                                <option value="<?php echo $i; ?>" <?php if ($f_region == $i) echo 'selected'; ?>>Region <?php echo $i; ?></option>
                            <?php } ?>
                            <option value="Redemption City">Redemption City</option>
                            <option value="National Headquarters">National Headquarters</option>
                            <option value="Continental 1 Headquarters">Continental 1 Headquarters</option>
                            <option value="Continental 2 Headquarters">Continental 2 Headquarters</option>
                            <option value="Continental 3 Headquarters">Continental 3 Headquarters</option>
                        </select>
                    </div>
                    <div class="col-md-4">
                        <label for="year" class="form-label">Select Year</label>
                        <select class="form-select" name="year" id="year">
                            <?php for ($year = date('Y'); $year >= 2000; $year--) { ?>
                                <option value="<?php echo $year; ?>" <?php if ($selected_year == $year) echo 'selected'; ?>><?php echo $year; ?></option>
                            <?php } ?>
                        </select>
                    </div>
                    <div class="col-md-4 d-flex align-items-end">
                        <button type="submit" class="btn btn-primary w-100">Filter</button>
                    </div>
                </div>
            </div>
        </form>
        <div class="card p-3 mb-3">

            <form action="upload.php" method="POST" enctype="multipart/form-data" class="mb-3">
                <input type="file" name="csv_file" required>
                <button type="submit" class="btn btn-primary">Upload & Approve Payments</button>
            </form>

            </form>
        </div>
        <div class="card p-3">
            <div class="table-responsive">
                <table id="paymentsTable" class="table table-striped">
                    <thead class="table-dark">
                        <tr>
                            <th>S/N</th>
                            <th>Name</th>
                            <th>Province</th>
                            <th>Amount Paid</th>
                            <th>Date of Payment</th>
                            <th>RRR</th>
                            <th>Status</th>
                            <th>Approved By</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        if (!empty($f_region)) {
                            $stmt = $conn->prepare("SELECT * FROM bank WHERE region = ? AND year = ?");
                            $stmt->execute([$f_region, $selected_year]);

                            $i = 1;
                            $hasRecords = false; // Flag to check if records exist

                            while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                                $hasRecords = true; // Set flag to true if records exist
                                echo "<tr id='row_{$row['rrr']}'>";
                                echo "<td>" . $i++ . "</td>";
                                echo "<td>{$row['name']}</td>";
                                echo "<td>{$row['province']}</td>";
                                echo "<td>₦" . number_format(floatval(str_replace(',', '', $row['cash'])), 2) . "</td>";
                                echo "<td>{$row['date_of_payment']}</td>";
                                echo "<td>{$row['rrr']}</td>";
                                echo "<td id='status_{$row['rrr']}'>{$row['status']}</td>";
                                echo "<td>{$row['approved_by']}</td>";
                                echo "<td style='white-space: nowrap;'>";
                                if ($row['status'] == "Pending") {
                                    echo "<button class='btn btn-warning approve-btn' data-rrr='{$row['rrr']}'>Approve</button>";
                                } else {
                                    echo "<button class='btn btn-success' disabled>Approved</button>";
                                    echo " <button class='btn btn-danger revert-btn' data-rrr='{$row['rrr']}'>Revert</button>";
                                }
                                echo "</td>";
                                echo "</tr>";
                            }

                            // If no records are found, display an alert message
                            if (!$hasRecords) {
                                echo "<tr><td colspan='9' class='text-center text-danger font-weight-bold'>No payment records found for the selected region and year!</td></tr>";
                            }
                        }
                        ?>
                    </tbody>
                </table>
            </div>
        </div>

<!-- Main Wrapper -->
<div class="wrapper">
    <!-- Your Page Content Here -->
</div>

<!-- Footer -->
<footer class="footer">
    &copy; <?php echo date("Y"); ?> PAYMENT AND REGISTRATION AGENT LOGIN. <br>
    <strong>Designed by Hi-Dev Solutions</strong>
</footer>

<style>
    .footer {
    width: 100%;
    text-align: center;
    padding: 15px 0;
    background-color: #f8f9fa; /* Light gray background */
    position: relative; /* Ensures it stays below content */
    margin-top: 30px; /* Adds spacing between body content and footer */
    font-size: 14px;
    font-weight: bold;
}

</style>

       <!-- Modal HTML -->
<div class="modal fade" id="welcomeModal" tabindex="-1" aria-labelledby="welcomeModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered"> <!-- Center Modal -->
        <div class="modal-content p-3 rounded shadow-lg">
            <div class="modal-header">
                <h5 class="modal-title fw-bold" id="welcomeModalLabel">🚀 Welcome to Payment Approval Page</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <p class="lead">Exciting updates to make your work easier:</p>
                <ul class="list-group list-group-flush">
                    <li class="list-group-item">✅ No more page refresh upon any payment approval; you will continue from where you are.</li>
                    <li class="list-group-item">✅ You can now demand a bank statement, upload the CSV, and the system will approve all matched records in the database.</li>
                    <li class="list-group-item">✅ Your name will be saved as the approver if you upload such a CSV file.</li>
                    <hr>
                    <li class="list-group-item">📢 <strong>New Features Available:</strong></li>
                    <li class="list-group-item">✅ You can now send notification messages to different provinces.</li>
                    <li class="list-group-item">✅ You can delete multiple notifications at once or delete/edit individual notifications.</li>
                    <li class="list-group-item">✅ You can update provinces and regions, create new ones, and assign regions to zones.</li>
                    <li class="list-group-item">✅ You can now switch between <strong>Dark Mode</strong> and <strong>Light Mode</strong> for a better experience.</li>
                </ul>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-success w-100" data-bs-dismiss="modal" id="closeModal">🎉 Got it!</button>
            </div>
        </div>
    </div>
</div>

        <!-- JavaScript -->
        <script>
            document.addEventListener("DOMContentLoaded", function() {
                // Show modal only once
                if (!localStorage.getItem("welcomeModalShown")) {
                    var welcomeModal = new bootstrap.Modal(document.getElementById("welcomeModal"));
                    welcomeModal.show();
                }

                document.getElementById("closeModal").addEventListener("click", function() {
                    localStorage.setItem("welcomeModalShown", "true");
                });

                // Dark Mode Toggle
                const themeToggle = document.getElementById("themeToggle");
                const body = document.body;
                const cards = document.querySelectorAll(".card");

                function setTheme(mode) {
                    if (mode === "dark") {
                        body.classList.add("dark-mode");
                        themeToggle.innerText = "☀️ Light Mode";
                        localStorage.setItem("theme", "dark");

                        // Change all cards to dark mode
                        cards.forEach(card => {
                            card.classList.add("dark-card");
                        });
                    } else {
                        body.classList.remove("dark-mode");
                        themeToggle.innerText = "🌙 Dark Mode";
                        localStorage.setItem("theme", "light");

                        // Revert cards back to light mode
                        cards.forEach(card => {
                            card.classList.remove("dark-card");
                        });
                    }
                }

                // Check saved theme preference
                const savedTheme = localStorage.getItem("theme") || "light";
                setTheme(savedTheme);

                // Toggle theme on button click
                themeToggle.addEventListener("click", function() {
                    const currentTheme = body.classList.contains("dark-mode") ? "light" : "dark";
                    setTheme(currentTheme);
                });
            });
        </script>

        <!-- Add Bootstrap & Custom CSS -->
        <style>
            /* General Dark Mode */
            .dark-mode {
                background-color: #121212;
                color: white;
            }

            /* Dark Mode for Modal */
            .dark-mode .modal-content {
                background-color: #1e1e1e;
                color: white;
                border: 1px solid #444;
            }

            .dark-mode .btn-close {
                filter: invert(1);
            }

            /* Dark Mode for Cards */
            .dark-card {
                background-color: #000 !important;
                color: white !important;
                border: 1px solid #444;
            }

            /* Light Mode for Cards */
            .card {
                background-color: white;
                color: black;
                border: 1px solid #ddd;
            }

            /* Dark Mode for List Items */
            .dark-mode .list-group-item {
                background-color: #2a2a2a;
                color: white;
                border-color: #444;
            }

            /* Center the Modal */
            .modal-dialog {
                display: flex;
                align-items: center;
                min-height: 100vh;
            }

            .modal-content {
                margin: auto;
            }
        </style>

        <!-- Bootstrap JS -->
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

        <script>
            $(document).ready(function() {
                // Event delegation for Approve button
                $(document).on("click", ".approve-btn", function(e) {
                    e.preventDefault();
                    let btn = $(this);
                    let rrr = btn.data("rrr");
                    let approved_by = "<?php echo $_SESSION['name']; ?>";

                    $.ajax({
                        url: "../verify.php",
                        type: "POST",
                        data: {
                            rrr: rrr,
                            approved_by: approved_by,
                            action: "approve"
                        },
                        dataType: "json",
                        success: function(response) {
                            alert(response.message);
                            if (response.success) {
                                $("#status_" + rrr).text("Approved");
                                $("#row_" + rrr + " td:nth-child(8)").text(response.approved_by);
                                btn.parent().html('<button class="btn btn-success" disabled>Approved</button> <button class="btn btn-danger revert-btn" data-rrr="' + rrr + '">Revert</button>');
                            }
                        }
                    });
                });

                // Event delegation for Revert button
                $(document).on("click", ".revert-btn", function(e) {
                    e.preventDefault();
                    let btn = $(this);
                    let rrr = btn.data("rrr");

                    if (!confirm("Are you sure you want to revert this payment to Pending?")) return;

                    $.ajax({
                        url: "../verify.php",
                        type: "POST",
                        data: {
                            rrr: rrr,
                            action: "revert"
                        },
                        dataType: "json",
                        success: function(response) {
                            alert(response.message);
                            if (response.success) {
                                $("#status_" + rrr).text("Pending");
                                $("#row_" + rrr + " td:nth-child(8)").text("");
                                btn.parent().html('<button class="btn btn-warning approve-btn" data-rrr="' + rrr + '">Approve</button>');
                            }
                        }
                    });
                });
            });
        </script>

</body>

</html>