<?php
session_start();
require_once '../conn.php'; // Ensure this file contains the $conn PDO connection

// Ensure session variable is set
if (!isset($_SESSION['name'])) {
    die("❌ Session expired. Please log in again.");
}

$agent_name = $_SESSION['name']; // Get the approving user
$approved_by = $agent_name; // Use the correct session variable

// Check if file is uploaded
if (!isset($_FILES['csv_file']) || $_FILES['csv_file']['error'] !== UPLOAD_ERR_OK) {
    die("❌ No file uploaded or upload error!");
}

// Open the uploaded CSV file
$csvFile = $_FILES['csv_file']['tmp_name'];
$handle = fopen($csvFile, "r");

if (!$handle) {
    die("❌ Failed to open file.");
}

$row_index = 0;
$approved_count = 0;

echo "<h3>🔍 Processing CSV File...</h3>";

// Read CSV rows
while (($row = fgetcsv($handle, 1000, ",")) !== FALSE) {
    $row_index++;

    if ($row_index == 1) {
        continue; // Skip header row
    }

    // Read relevant columns from CSV
    $transaction_date = trim($row[1] ?? ''); // Column B (Transaction Date)
    $transaction_details = trim($row[3] ?? ''); // Column D (Transaction Details - Name)
    $lodgment = trim($row[6] ?? ''); // Column G (Amount Paid)

    // Convert date format from MM/DD/YYYY to YYYY-MM-DD
    if (!empty($transaction_date)) {
        $transaction_date = date('Y-m-d', strtotime(str_replace('/', '-', $transaction_date)));
    }

    // Clean Amount (Remove Naira Symbol and convert to integer)
    $lodgment = preg_replace('/[^\d.]/', '', $lodgment); // Remove ₦ or any non-numeric characters
    $lodgment = (float)$lodgment; // Convert to float
    $lodgment = intval($lodgment); // Convert to integer to match DB format

    // Debugging: Print mapped values
    echo "<p>➡ Checking: <strong>Name:</strong> {$transaction_details}, <strong>Date:</strong> {$transaction_date}, <strong>Amount:</strong> {$lodgment}</p>";

    // Ensure data is valid before proceeding
    if (!empty($transaction_details) && !empty($transaction_date) && !empty($lodgment)) {
        // Search for partial match of transaction_details in the database, IGNORING DATE
        $stmt = $conn->prepare("SELECT * FROM bank WHERE name LIKE ? AND cash = ? AND status = 'Pending'");
        $stmt->execute(["%$transaction_details%", $lodgment]);

        if ($stmt->rowCount() > 0) {
            echo "<span style='color:green;'>✅ MATCH FOUND! Approving...</span><br>";

            // Get the exact name from the database
            $bank_record = $stmt->fetch(PDO::FETCH_ASSOC);
            $matched_name = $bank_record['name']; // Get the matched name from DB
            $db_date = $bank_record['date']; // Date from the DB

            echo "<p>🟡 Database Date: {$db_date} | CSV Date: {$transaction_date}</p>";

            // Approve transaction in DB
            $update = $conn->prepare("UPDATE bank SET status='Approved', approved_by=? WHERE name=? AND cash=?");
            $update->execute([$approved_by, $matched_name, $lodgment]);

            $approved_count++;
        } else {
            echo "<span style='color:red;'>❌ NO MATCH FOUND in DB!</span><br>";
        }
    } else {
        echo "<span style='color:orange;'>⚠ Skipping row due to missing data.</span><br>";
    }
}

fclose($handle);
echo "<h3>✅ Successfully approved {$approved_count} payments.</h3>";

// Redirect after successful approval
header("Location: approval_page.php");
exit();
?>
