<?php
session_start(); // Start the session

require_once("conn.php"); // Ensure the database connection is included

// Check if the checkout form was submitted
if (isset($_POST['checkout'])) {
    // Sanitize and validate user inputs
    $name = htmlspecialchars(trim($_POST['name']));
    $email = filter_var(trim($_POST['email']), FILTER_VALIDATE_EMAIL);
    $phoneNumber = htmlspecialchars(trim($_POST['phone_number']));
    $referenceCode = htmlspecialchars(trim($_POST['teller_number']));
    $region = htmlspecialchars(trim($_POST['region']));
    $province = htmlspecialchars(trim($_POST['province']));
    $zone = htmlspecialchars(trim($_POST['zone']));

    if (!$email) {
        echo '<script>alert("Invalid email address."); window.location.href = "newregistration.php";</script>';
        exit();
    }

    // Initialize counters
    $p1 = 0; // Children's tickets
    $p2 = 0; // Teen tickets
    $p3 = 0; // Teacher tickets
    $cartTotal = 0; // Total amount

    // Fetch product details from the database
    $stmt = $conn->query("SELECT id, name FROM products");
    $productMapping = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Map product IDs to types
    $productTypes = [];
    foreach ($productMapping as $product) {
        switch (strtolower($product['name'])) {
            case 'children\'s ticket':
                $productTypes[$product['id']] = 'p1';
                break;
            case 'teens ticket':
                $productTypes[$product['id']] = 'p2';
                break;
            case 'teacher\'s ticket':
                $productTypes[$product['id']] = 'p3';
                break;
            default:
                // Handle unknown product types if necessary
                break;
        }
    }

    // Process cart items
    if (!empty($_SESSION['cart'])) {
        foreach ($_SESSION['cart'] as $item) {
            $itemPrice = $item['price'];
            $itemQuantity = $item['quantity'];
            $productId = $item['id'];

            // Determine ticket type based on product ID
            if (isset($productTypes[$productId])) {
                $type = $productTypes[$productId];
                switch ($type) {
                    case 'p1':
                        $p1 += (int)$itemQuantity;
                        break;
                    case 'p2':
                        $p2 += (int)$itemQuantity;
                        break;
                    case 'p3':
                        $p3 += (int)$itemQuantity;
                        break;
                    default:
                        // Handle unknown types if necessary
                        break;
                }
            }

            $cartTotal += $itemPrice * $itemQuantity;
        }
    } else {
        echo '<script>alert("Your cart is empty. Please add items before proceeding to checkout."); window.location.href = "shop.php";</script>';
        exit();
    }

    if ($p1 + $p2 + $p3 < 1) {
        echo '<script>alert("Sorry, the minimum number of Registration you can book is 1."); window.location.href = "newregistration.php";</script>';
        exit();
    }

    // Check if the province has incomplete registrations
    $stmt = $conn->prepare("SELECT * FROM registration WHERE province = ? AND (p1 != p1c OR p2 != p2c OR p3 != p3c)");
    $stmt->execute([$province]);
    $incompleteRegistration = $stmt->fetch();

    if ($incompleteRegistration) {
        echo '<script>alert("You cannot generate another RRR code until you complete the previous registration for this province."); window.location.href = "regcontinue.php";</script>';
        exit();
    }

    // Check if a similar record already exists
    $stmt = $conn->prepare("SELECT COUNT(*) FROM registration WHERE name = ? AND email = ? AND phone_number = ? AND password = ?");
    $stmt->execute([$name, $email, $phoneNumber, $referenceCode]);
    $recordExists = $stmt->fetchColumn();

    if ($recordExists) {
        echo '<script>alert("A similar registration already exists. Please avoid duplicate entries."); window.location.href = "newregistration.php";</script>';
        exit();
    }

    // Get the current date and time
    $registrationDateTime = date("l, jS F - h:i:s A"); // e.g., Thursday, 29th August - 06:27:27 PM
    $registrationYear = date("Y"); // e.g., 2024

    // Save details into the registration table
    $stmt = $conn->prepare("INSERT INTO registration (name, email, phone_number, password, zone, region, province, p1, p2, p3, amount, date, year) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
    $success = $stmt->execute([
        $name,
        $email,
        $phoneNumber,
        $referenceCode,
        $zone,
        $region,
        $province,
        $p1,
        $p2,
        $p3,
        $cartTotal,
        $registrationDateTime,
        $registrationYear
    ]);

    if ($success) {
        // Save details in the session
        $_SESSION['registration_details'] = [
            'name' => $name,
            'email' => $email,
            'phone_number' => $phoneNumber,
            'reference_code' => $referenceCode,
            'zone' => $zone,
            'region' => $region,
            'province' => $province,
            'p1' => $p1,
            'p2' => $p2,
            'p3' => $p3,
            'amount' => $cartTotal,
            'registration_date_time' => $registrationDateTime,
            'registration_year' => $registrationYear
        ];

        // Clear the cart after successful registration
        unset($_SESSION['cart']);

        // Retrieve the last inserted ID
        $registrationId = $conn->lastInsertId();

        // Redirect to summary page
        echo '<script>
            alert("Thank you, you have booked ' . ($p1 + $p2 + $p3) . ' Registration Tickets.");
            window.location.href = "summary.php?registration_id=' . htmlspecialchars($referenceCode, ENT_QUOTES, 'UTF-8') . '";
        </script>';
        exit(); // Ensure the script stops after redirection
    } else {
        echo '<script>alert("There was an error processing your registration. Please try again."); window.location.href = "newregistration.php";</script>';
        exit();
    }
}
?>
