<?php
session_start();

include 'conn.php';

// Redirect to login if the user is not authenticated
// Check if the session 'pro' is set, if not redirect to login page
if (!isset($_SESSION['reg']) || !isset($_SESSION['pro']) || !isset($_SESSION['zone'])) {
    // Redirect to the login page if not logged in
    header("Location: index.php"); // Change to your login page URL
    exit();
}

// Check if it's a fresh login and clear the cart and reference code
if (isset($_SESSION['freshLogin']) && $_SESSION['freshLogin']) {
    $_SESSION['cart'] = [];
    unset($_SESSION['referenceCode']);
    $_SESSION['freshLogin'] = false;
}

// Initialize the cart if not already set
if (!isset($_SESSION['cart'])) {
    $_SESSION['cart'] = [];
}

// Add the product to the cart
if (isset($_POST['add_to_cart'])) {
    $product_id = $_POST['product_id'];
    $product_name = $_POST['product_name'];
    $product_price = $_POST['product_price'];

    $product_found = false;

    // Update the quantity if the product is already in the cart
    foreach ($_SESSION['cart'] as &$item) {
        if ($item['id'] == $product_id) {
            $item['quantity'] += 1;
            $product_found = true;
            break;
        }
    }

    // If the product is not in the cart, add it
    if (!$product_found) {
        $_SESSION['cart'][] = [
            'id' => $product_id,
            'name' => $product_name,
            'price' => $product_price,
            'quantity' => 1,
        ];
    }
}

// Handle quantity update
if (isset($_POST['update_quantity'])) {
    $item_id = $_POST['item_id'];
    $new_quantity = intval($_POST['new_quantity']);

    // Update the quantity or remove the item if quantity is zero or less
    foreach ($_SESSION['cart'] as &$item) {
        if ($item['id'] == $item_id) {
            if ($new_quantity > 0) {
                $item['quantity'] = $new_quantity;
            } else {
                $item = null; // Mark for removal
            }
            break;
        }
    }

    // Remove any null items and reindex the cart array
    $_SESSION['cart'] = array_values(array_filter($_SESSION['cart']));
}

// Remove an item from the cart
if (isset($_POST['remove_item'])) {
    $item_id = $_POST['item_id'];

    // Remove the item if it exists
    $_SESSION['cart'] = array_values(array_filter($_SESSION['cart'], function ($item) use ($item_id) {
        return $item['id'] != $item_id;
    }));
}

// Check for incomplete registrations
$province = $_SESSION['pro']; // Ensure you set the province correctly
$stmt = $conn->prepare("SELECT * FROM registration WHERE province = ? AND (p1 != p1c OR p2 != p2c OR p3 != p3c)");
$stmt->execute([$province]);
$incompleteRegistration = $stmt->fetch();

// Handle the "Generate Reference Code" button
if (isset($_POST['generate_reference_code'])) {
    if ($incompleteRegistration) {
        echo '<script>alert("You cannot generate another RRR code until you complete the previous registration for this province."); window.location.href = "regcontinue.php";</script>';
        exit();
    } else {
        $_SESSION['referenceCode'] = generateReferenceCode();
        echo '<script>alert("New RRR code generated: ' . $_SESSION['referenceCode'] . '");</script>';
    }
}

// Function to generate the reference code
function generateReferenceCode()
{
    $characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
    $referenceCode = '';
    for ($i = 0; $i < 11; $i++) {
        $referenceCode .= $characters[random_int(0, strlen($characters) - 1)];
    }
    return $referenceCode;
}

// Handle empty cart action
if (isset($_POST['empty_cart'])) {
    $_SESSION['cart'] = [];
    header("Location: newregistration.php?message=Cart+has+been+emptied");
    exit();
}

// Define if the cart is empty
$is_cart_empty = empty($_SESSION['cart']);
?>




<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>RCCG DTCE | New Registration</title>

    <!-- Dependencies -->
    <link rel="stylesheet" href="plugins/fontawesome-free/css/all.min.css">
    <link rel="stylesheet" href="plugins/icheck-bootstrap/icheck-bootstrap.min.css">
    <link rel="stylesheet" href="plugins/password-requirement/css/jquery.passwordRequirements.css">
    <link rel="stylesheet" href="dist/css/adminlte.min.css">
    <link rel="stylesheet" href="cookies/cookieconsent.css">
    <link rel="stylesheet" href="plugins/sweetalert2-theme-bootstrap-4/bootstrap-4.min.css">
    <link rel="stylesheet" href="dist/css/custom.css">
    <link rel="stylesheet" href="dist/css/login_style.css">
    <link rel="stylesheet" href="assets/css/mystyle.css">
    <link rel="stylesheet" href="dist/css/animate.min.css">
    <link href="plugins/intl-tel-input-17.0.0/build/css/intlTelInput.min.css" rel="stylesheet" type="text/css" />
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-icons/1.8.1/font/bootstrap-icons.min.css">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>
    <!-- AdminLTE -->
    <script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>



    <style>
       /* Main theme Default light mode (bootstrap defaults) */
       body {
            background-color: #ffffff;
            color: #000000;
            transition: background-color 0.3s, color 0.3s;
        }

        
        a {
            color:rgb(12, 12, 12);
        }

        a:hover {
            color: #0056b3;
        }

        /* Dark Mode - Links */
.dark-mode .strip_2 a {
    color: rgb(241, 239, 239) !important; /* Light color for better contrast */
    text-decoration: none; /* Optional: Removes underline for a cleaner look */
}

/* Dark Mode - Links on Hover */
.dark-mode .strip_2 a:hover {
    color: #4a90e2 !important; /* A softer blue for better readability */
    text-decoration: underline; /* Optional: Adds underline on hover */
}


        .light-mode .province-initials {
            background-color: #007bff !important;
            color: white !important;
            /* border: 1px solid white !important; */
        }

        .light-mode .alert,
        .dropdown-menu,
        .dropdown-menu-lg,
        .dropdown-menu-right,
        .dropdown-item {
            background-color: white !important;
            color: black !important;
            border-color: #444 !important;
        }

        /* Dark Mode */
        .dark-mode {
            background-color: #121212 !important;
            color: #ffffff !important;
        }

        /* Dark mode for links */
        .dark-mode a {
            color: rgb(247, 249, 252) !important;
        }

        .dark-mode a:hover {
            color: rgb(243, 248, 253) !important;
        }

        /* Dark mode for navigation bar */
        .dark-mode .navbar {
            background-color: #1e1e1e !important;
            border-bottom: 1px solid #333 !important;
        }

        .dark-mode .navbar a {
            color: white !important;
        }

        .dark-mode .navbar a:hover {
            color: #ccc !important;
        }

        /* Dark mode for buttons */
        .dark-mode .btn {
            background-color: #333 !important;
            color: white !important;
            /* border: 1px solid white !important; */
        }

        .dark-mode .btn:hover {
            background-color: white !important;
        }

        /* Specific button colors in dark mode */
        .dark-mode .btn-primary {
            background-color: rgb(0, 3, 7) !important;
            color: white !important;
        }

        .dark-mode .btn-success {
            background-color: rgb(1, 12, 3) !important;
            color: white !important;
        }

        .dark-mode .btn-danger {
            background-color: rgb(8, 0, 1) !important;
            color: white !important;
        }

        .dark-mode .btn-warning {
            background-color: rgb(2, 1, 0) !important;
            color: white !important;
        }

        .dark-mode .btn-info {
            background-color: rgb(0, 7, 8) !important;
            color: white !important;
        }

        /* Dark mode for tables */
        .dark-mode table {
            background-color: #1e1e1e !important;
            color: white !important;
        }

        .dark-mode thead {
            background-color: #333 !important;
        }

        .dark-mode tbody tr {
            background-color: #2c2c2c !important;
        }

        .dark-mode tbody tr:hover {
            background-color: #3a3a3a !important;
        }

        /* Dark mode for form fields */
        .dark-mode input,
        .dark-mode select,
        .dark-mode textarea {
            background-color: #222 !important;
            color: white !important;
            border: 1px solid white !important;
        }

        .dark-mode input::placeholder,
        .dark-mode textarea::placeholder {
            color: #bbb !important;
        }

        /* Dark mode for modals */
        .dark-mode .modal-content {
            background-color: #1e1e1e !important;
            color: white !important;
        }

        .dark-mode .modal-header {
            border-bottom: 1px solid #333 !important;
        }

        .dark-mode .modal-footer {
            border-top: 1px solid #333 !important;
        }

        /* Dark mode for sidebar (if applicable) */
        .dark-mode .sidebar {
            background-color: #1e1e1e !important;
        }

        .dark-mode .sidebar a {
            color: white !important;
        }

        .dark-mode .sidebar a:hover {
            color: #ccc !important;
        }

        /* Dark mode for alerts */
        .dark-mode .alert,
        .dropdown-menu,
        .dropdown-menu-lg,
        .dropdown-menu-right,
        .dropdown-item {
            background-color: #333 !important;
            color: white !important;
            border-color: #444 !important;
        }


        /* Default (Light Mode) */
        .alert,
        .dropdown-menu,
        .dropdown-menu-lg,
        .dropdown-menu-right,
        .dropdown-item {
            background-color: #ffffff !important;
            /* Light background */
            color: #000000 !important;
            /* Dark text */
            border-color: #ddd !important;
            /* Light border */
        }

        /* Hover effect in light mode */
        .dropdown-item:hover {
            background-color: #f8f9fa !important;
            color: #000000 !important;
        }

        /* Dark Mode */
        .dark-mode .alert,
        .dark-mode .dropdown-menu,
        .dark-mode .dropdown-menu-lg,
        .dark-mode .dropdown-menu-right,
        .dark-mode .dropdown-item {
            background-color: #222 !important;
            /* Dark background */
            color: #ffffff !important;
            /* Light text */
            border-color: #444 !important;
            /* Dark border */
        }

        /* Hover effect in dark mode */
        .dark-mode .dropdown-item:hover {
            background-color: #333 !important;
            color: #ffffff !important;
        }

        /* Light Mode */
        .toast-body,
        .toast-header {
            background-color: #ffffff !important;
            /* White background */
            color: #000000 !important;
            /* Black text */
            border-color: #ddd !important;
            /* Light grey border */
        }
/* Light Mode - Paragraph Specific */


/* Light Mode - Paragraph on Blue Background */
.sidebar-dark-primary p,
.main-sidebar p {
    color: white !important; /* White text on blue backgrounds */
} 

.sidebar-dark-primary .fa,
.main-sidebar .fa {
    color: white !important; /* White text on blue backgrounds */
} 
        /* Light Mode (Default) */
        
        p,
        h1,
        h2,
        h3,
        h4,
        h5,
        h6,
        .card-title,
        .text-dark,
        .text-secondary,
        .text-muted,
        .text-primary {
            color:rgb(12, 0, 0) !important;
            /* Default dark text */
        }


        .fa {
            color:white;
        }
        /* Dark Mode Styles */
        .dark-mode {
            background-color: #121212 !important;
            /* Dark background */
            color: #ffffff !important;
            /* Light text */
        }

        /* Dark Mode Text Colors */
        .dark-mode .fa,
        .dark-mode p,
        .dark-mode h1,
        .dark-mode h2,
        .dark-mode h3,
        .dark-mode h4,
        .dark-mode h5,
        .dark-mode h6,
        .dark-mode .card-title,
        .dark-mode .text-dark,
        .dark-mode .text-secondary,
        .dark-mode .text-muted,
        .dark-mode .text-primary {
            color: #ffffff !important;
            /* White text in dark mode */
        }
        
        .dark-mode .strip-wrapper{
            background-color:none;
            color:black;
        }
        
    
      .strip_2,.strip-wrapper{
            background-color:none;
            color: black;
        }
        

        .card-title,
         .text-dark,
         .text-secondary,
         .text-muted,
         .text-primary {
            color:rgb(7, 6, 6) !important;
            /* White text in dark mode */
        }


        /* Adjust Specific Text Colors in Dark Mode */
        .dark-mode .text-muted {
            color: #b0b0b0 !important;
            /* Slightly gray for muted text */
        }

        .dark-mode .text-primary {
            color:rgb(237, 241, 245) !important;
            /* Lighter blue for better contrast */
        }

        .dark-mode .text-secondary {
            color: #adb5bd !important;
            /* Light grayish text */
        }

        /* Dark Mode Background for Cards & Containers */
        .dark-mode .card,
        .dark-mode .modal-content,
        .dark-mode .dropdown-menu,
        .dark-mode .toast-body,
        .dark-mode .toast-header {
            background-color: #222 !important;
            color: white !important;
            border-color: #444 !important;
        }

        /* Dark Mode FA Icons */
        .dark-mode .fa {
            color: #ffffff !important;
            /* White icons in dark mode */
        }

        /* Dark Mode Specific Icons */
        .dark-mode .fa-calendar {
            color:rgb(236, 235, 229) !important;
            /* Yellow */
        }
        .fa-calendar {
            color:#007bff !important;
            /* Yellow */
        }

        .dark-mode .fa-user {
            color:rgb(242, 247, 248) !important;
            /* Bootstrap info blue */
        }

        .dark-mode .fa-cog, .fa-clock  {
            color: #f8f9fa !important;
            /* Light gray */
        }
         .fa-cog, .fa-clock, .fa-user  {
            color:rgb(1, 5, 10) !important;
            /* Light gray */
        }

        /* Dark Mode Buttons */
        .dark-mode .btn {
            background-color: #333 !important;
            color: #ffffff !important;
            border: 1px solid #555 !important;
        }

        .dark-mode .btn-primary {
            background-color:rgb(11, 12, 12) !important;
            border-color:rgb(8, 8, 8) !important;
        }

        .dark-mode .btn-secondary {
            background-color: #6c757d !important;
            border-color: #6c757d !important;
        }

        /* Hover Effects */
        .dark-mode .btn:hover {
            background-color: #444 !important;
        }

        .dark-mode .btn-primary:hover {
            background-color:rgb(17, 17, 19) !important;
        }

        .dark-mode .btn-secondary:hover {
            background-color: #5a6268 !important;
        }



        /* Toast header specific styling */
        .toast-header {
            font-weight: bold;
            border-bottom: 1px solid #ddd !important;
        }

        /* Dark Mode */
        .dark-mode .toast-body,
        .dark-mode .toast-header {
            background-color: #222 !important;
            /* Dark background */
            color: #ffffff !important;
            /* White text */
            border-color: #444 !important;
            /* Dark grey border */
        }
        
         /* Light Mode - Toast Styling */
.toast-body,
.toast-header {
    background-color: white !important; /* White background */
    color: rgb(15, 15, 15) !important; /* Dark text */
    border-color: #ddd !important; /* Light grey border */
}

/* Light Mode - Toast Header */
.toast-header {
    font-weight: bold;
    border-bottom: 1px solid #ccc !important; /* Light grey separator */
}

        /* Toast header specific styling */
        .dark-mode .toast-header {
            font-weight: bold;
            border-bottom: 1px solid #444 !important;
        }
        


        /* Dark mode for card components */
        .dark-mode .card {
            background-color: #222 !important;
            color: white !important;
            /* border: 1px solid white !important; */
        }

        .dark-mode .card-header {
            background-color: #1e1e1e !important;
        }

        /* Toggle Button Fix */
        .dark-mode #theme-toggle {
            /* background-color: #222 !important; */
            color: white !important;
            /* border: 1px solid white !important; */
        }

        .dark-mode .badge-danger,
        .province-initials {
            background-color: white !important;
            color: black !important;
            /* border: 1px solid white !important; */
        }
        .mb-custom {
            margin-bottom: 1.5rem;
            /* Adjust this value to control spacing between rows */
        }

        .first-row-spacing {
            margin-top: 2rem;
            /* Adjust this value to control spacing before the first row */
        }

        .dark-mode .btn-primary {
            color: white;
            background: black;
            border: 2px solid #000;
        }

        .dark-mode small {
            color: white;
            font-weight: bold;
        }

        .light-mode small {
            color: black;
            font-weight: bold;
        }

        /* Style for a disabled button */
        /* Apply the "not-allowed" cursor to the disabled button */
        .btn.btn-primary:disabled {
            cursor: not-allowed;
        }

        /* Apply the "pointer" cursor to the enabled button */
        .disabled-button {
            opacity: 0.6;
            cursor: not-allowed;
        }

        .center-button-container {
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            margin-top: 1rem;
            /* Add margin if needed */
        }

        .button-group {
            display: flex;
            gap: 1rem;
            /* Adjust spacing between buttons */
        }

        .btn-custom {
            padding: 0.25rem 0.5rem;
            /* Adjust padding for a smaller button */
            font-size: 0.875rem;
            /* Adjust font size for smaller text */
            display: flex;
            align-items: center;
            gap: 0.5rem;
            /* Space between icon and text */
        }

        #checkoutButton {
            padding: 0.25rem 0.5rem;
            /* Adjust padding for a smaller button */
            font-size: 0.875rem;
            /* Adjust font size for smaller text */
            display: flex;
            align-items: center;
            gap: 0.5rem;
            /* Space between icon and text */
        }
    </style>


</head>

<body class="hold-transition sidebar-mini layout-fixed">
<div class="wrapper">
    <!-- Navbar -->
    <nav class="main-header navbar navbar-expand-lg navbar-light">
        <div class="container-fluid">
            <!-- Navbar Toggler for Mobile -->
            <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
                aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>

            <!-- Left Navbar Links -->
            <a href="#" class="navbar-brand">
                <img src="./dist/img/dtce.png" alt="Logo" style="height: 40px;">
            </a>

            <?php
            include 'conn.php';
            $province_name = $_SESSION['pro']; // Get the province name from the session

            // Fetch the count of unread notifications for this province
            $stmt = $conn->prepare("SELECT COUNT(*) as count FROM notifications WHERE province = :province AND is_read = 0");
            $stmt->bindValue(':province', $province_name);
            $stmt->execute();
            $count = $stmt->fetch(PDO::FETCH_ASSOC)['count'];
            ?>

            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" data-widget="pushmenu" href="#" role="button">
                            <i class="fas fa-bars"></i>
                        </a>
                    </li>
                </ul>

                <!-- Centered Search Form -->
                <form class="form-inline mx-auto">
                    <input class="form-control mr-sm-2" type="search" placeholder="Search" aria-label="Search">
                    <button class="btn btn-outline-primary my-2 my-sm-0" type="submit">
                        <i class="fas fa-search"></i>
                    </button>
                </form>

                <!-- Right Navbar Links -->
                <ul class="navbar-nav ml-auto">
                    <li class="nav-item">
                        <a class="nav-link" href="#">
                            <img src="./dist/img/ng3.webp" alt="Flag" style="width: 35px;">
                        </a>
                    </li>

                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="notificationDropdown" role="button"
                            data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                            <i class="fas fa-bell">
                                <span class="badge badge-danger"><?php echo $count; ?></span>
                            </i>
                        </a>
                        <div class="dropdown-menu dropdown-menu-right" aria-labelledby="notificationDropdown"
                            id="notificationList">
                            <!-- Notifications will be loaded here -->
                        </div>
                    </li>

                    <li class="nav-item">
                        <a class="nav-link" href="#" id="theme-toggle">
                            <i id="theme-icon" class="fas fa-sun"></i> <!-- Default icon is sun -->
                        </a>
                    </li>

                    <li class="nav-item dropdown">
                        <a class="nav-link d-flex align-items-center dropdown-toggle" data-toggle="dropdown" href="#">
                            <?php
                            // Extract initials from the province name
                            $province = $_SESSION["pro"];
                            $province_parts = explode(" ", $province);
                            $initials = strtoupper(substr($province_parts[0], 0, 1)) . strtoupper(substr($province_parts[1], 0, 1));
                            $number = isset($province_parts[2]) ? $province_parts[2] : '';

                            // Display the initials and the number
                            echo '<div class="province-initials"
                                style="background-color: #007bff; color: white; width: 45px; height: 45px; border-radius: 50%; display: flex; justify-content: center; align-items: center; margin-right: 10px; font-weight: bold; font-size: 16px;">';
                            echo $initials . ' ' . $number;
                            echo '</div>';
                            ?>

                            <div style="display: flex; flex-direction: column;">
                                <span class="d-none d-md-inline"><?php echo $_SESSION["pro"] ?></span>
                                <small><?php echo $_SESSION["zone"] ?></small>
                            </div>
                        </a>
                        <div class="dropdown-menu dropdown-menu-lg dropdown-menu-right">
                            <a href="#" class="dropdown-item"><i class="fas fa-user"></i> My Profile</a>
                            <a href="#" class="dropdown-item"><i class="fas fa-cog"></i> Settings</a>
                            <div class="dropdown-divider"></div>
                            <a href="logout.php" class="dropdown-item"><i class="fas fa-sign-out-alt"></i> Logout</a>
                        </div>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
</div>

        <!-- /.navbar -->

        <!-- Main Sidebar Container -->
        <aside class="main-sidebar sidebar-dark-primary elevation-4">
            <!-- Sidebar -->
            <div class="sidebar">
                <!-- Sidebar user panel -->
                <div class="user-panel mt-3 pb-3 mb-3 d-flex">
                    <div class="image">
                        <img src="./dist/img/icon.png" alt="User Image">
                    </div>
                    <div class="info">
                        <a href="#" class="d-block">RCCG DTCE</a>
                    </div>
                </div>

               <!-- Sidebar Menu -->
               <?php
// Include your database connection file
include 'conn.php';

// Fetch menu items, ordered by the 'order' field
$stmt = $conn->query("SELECT * FROM navbars WHERE status = 'active' ORDER BY `order` ASC");
$menuItems = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!-- Sidebar Menu -->
<nav class="mt-2">
    <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">
        <?php foreach ($menuItems as $item): ?>
            <li class="nav-item">
                <a href="<?php echo htmlspecialchars($item['link']); ?>" class="nav-link">
                    <i class="nav-icon fas <?php echo htmlspecialchars($item['icon']); ?>"></i>
                    <p style="color: white;"><?php echo htmlspecialchars($item['name']); ?></p>
                </a>
            </li>
        <?php endforeach; ?>
    </ul>
</nav>


                <!-- /.sidebar-menu -->
            </div>
            <!-- /.sidebar -->
        </aside>

        <!-- Content Wrapper -->
        <div class="content-wrapper">
            <!-- Breadcrumb -->
            <div class="breadcrumb-wrapper">
                <ul class="breadcrumb">
                    <li class="breadcrumb-item"><a href="../../index.php">HOME</a></li>
                    <li class="breadcrumb-item active">New Registration</li>
                </ul>
            </div>

            <?php include("news.php"); ?>
            <!-- Main content -->

            <section class="content">
                <!-- <?php
                        include 'conn.php';

                        // Fetch the cover picture
                        $stmt = $conn->query("SELECT * FROM cover_pic ORDER BY id DESC LIMIT 1");
                        $coverPic = $stmt->fetch(PDO::FETCH_ASSOC);

                        $imagePath = $coverPic ? $coverPic['image_path'] : './dist/img/bg-login.jpg'; // Default image if none found
                        ?>

<div class="row">
    <div class="col-sm-12">
        <div class="profile-bg-picture" style="background-image: url('<?php echo htmlspecialchars($imagePath); ?>');">
            <div class="picture-bg-overlay"></div>
        </div>
    </div>
</div> -->

                <?php
                include 'conn.php'; // Include your database connection file

                // Fetch products from the database
                $sql = 'SELECT * FROM products'; // Adjust the query as needed
                $stmt = $conn->query($sql);
                $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
                ?>

                <div class="container mt-5">
                    <div class="row justify-content-center">
                        <?php foreach ($products as $product): ?>
                            <div class="col-md-3 mb-4">
                                <div class="card" style="border-radius: 15px; box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2), 0 6px 20px rgba(0, 0, 0, 0.19);">
                                    <img src="<?php echo htmlspecialchars($product['image_path']); ?>" class="card-img-top" alt="<?php echo htmlspecialchars($product['name']); ?>">
                                    <div class="card-body text-center">
                                        <h5 class="card-title"><?php echo htmlspecialchars($product['name']); ?></h5>
                                        <h3 class="card-text">₦<?php echo number_format($product['price'], 2); ?></h3>
                                        <p class="card-text"><strong>Slug:</strong> <?php echo htmlspecialchars($product['slug']); ?></p> <!-- Display the slug here -->
                                        <form method="post" action="add_to_cart.php">
                                            <input type="hidden" name="product_id" value="<?php echo htmlspecialchars($product['id']); ?>">
                                            <input type="hidden" name="product_name" value="<?php echo htmlspecialchars($product['name']); ?>">
                                            <input type="hidden" name="product_price" value="<?php echo htmlspecialchars($product['price']); ?>">
                                            <!-- Add to Cart Button with Icon -->
                                            <button type="submit" name="add_to_cart" class="btn btn-primary">
                                                <i class="fa fa-cart-plus"></i> Add to Cart
                                            </button>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>


                <?php

                // // Check if the cart is not empty
                // $is_cart_empty = empty($_SESSION['cart']);
                //   // Debug: Display session cart data
                //   echo '<pre>';
                //   var_dump($_SESSION['cart']);
                //   echo '</pre>';
                ?>

                <?php

                ?>

                <!-- Shopping Cart Section -->
                <div class="container mt-5">
                    <div class="row">
                        <div class="col-md-12">
                            <div class="card">
                                <div class="card-body">
                                    <h2 class="mt-4">Shopping Cart</h2>

                                    <!-- Display success message if set -->
                                    <?php if (isset($_GET['message'])): ?>
                                        <div class="alert alert-success alert-dismissible fade show" role="alert">
                                            <?php echo htmlspecialchars($_GET['message']); ?>
                                            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                                <span aria-hidden="true">&times;</span>
                                            </button>
                                        </div>
                                        <script>
                                            // Auto-dismiss alert after 5 seconds
                                            setTimeout(function() {
                                                $('.alert').alert('close');
                                            }, 5000);
                                        </script>
                                    <?php endif; ?>

                                    <div class="table-responsive">
                                        <table class="table table-bordered">
                                            <thead>
                                                <tr>
                                                    <th>Product</th>
                                                    <th class="text-right">Price</th>
                                                    <th>Quantity</th>
                                                    <th class="text-right">Subtotal</th>
                                                    <th>Action</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php
                                                $is_cart_empty = empty($_SESSION['cart']);
                                                if (!$is_cart_empty) {
                                                    $item_total = 0;
                                                    foreach ($_SESSION['cart'] as $productId => $item) {
                                                        if ($item['quantity'] > 0) {
                                                            echo '<tr>';
                                                            echo '<td>' . htmlspecialchars($item['name']) . '</td>';
                                                            echo '<td class="text-right">₦' . number_format($item['price'], 2) . '</td>';
                                                            echo '<td>
                                                    <form method="post" action="update_cart.php">
                                                        <input type="hidden" name="item_id" value="' . htmlspecialchars($productId) . '">
                                                        <div class="input-group">
                                                            <input type="number" name="new_quantity" value="' . htmlspecialchars($item['quantity']) . '" min="1" class="form-control">
                                                            <div class="input-group-append">
                                                                <button type="submit" name="update_quantity" class="btn btn-primary">Update</button>
                                                            </div>
                                                        </div>
                                                    </form>
                                                </td>';
                                                            echo '<td class="text-right">₦' . number_format($item['price'] * $item['quantity'], 2) . '</td>';
                                                            echo '<td>
                                                    <form method="post" action="update_cart.php" onsubmit="return confirm(\'Are you sure you want to remove this item?\');">
                                                        <input type="hidden" name="item_id" value="' . htmlspecialchars($productId) . '">
                                                        <button type="submit" name="remove_item" class="btn btn-danger" aria-label="Remove item"><i class="fa fa-trash"></i></button>
                                                    </form>
                                                </td>';
                                                            echo '</tr>';
                                                            $item_total += $item['price'] * $item['quantity'];
                                                        }
                                                    }
                                                    echo '<tr>';
                                                    echo '<td colspan="3"><strong>Total</strong></td>';
                                                    echo '<td class="text-right">₦' . number_format($item_total, 2) . '</td>';
                                                    echo '<td class="text-center">
                                            <form action="" method="post">
                                                <button type="submit" name="empty_cart" class="btn btn-danger btn-custom">
                                                    <i class="fa fa-trash"></i> 
                                                    Empty Cart
                                                </button>
                                            </form>
                                        </td>';
                                                    echo '</tr>';
                                                } else {
                                                    echo '<tr><td colspan="5" style="text-align: center;">Your cart is empty.</td></tr>';
                                                }
                                                ?>
                                            </tbody>
                                        </table>
                                    </div>

                                    <!-- Container for centering the Check Out button -->
                                    <div class="center-button-container text-center mt-4">
                                        <!-- Show Check Out Button Only If Cart Is Not Empty -->
                                        <?php if (!$is_cart_empty): ?>
                                            <a href="checkout.php" class="btn btn-secondary btn-custom" id="checkoutButton2">
                                                <i class="fa fa-shopping-cart"></i>
                                                Check Out
                                            </a>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Billing Details Section -->
                <div class="container mt-5" id="billingDetails" style="display: none;">
                    <div class="row">
                        <div class="col-md-6">
                            <div class="card-body">
                                <h3 class="billing-detail-heading">Billing Details</h3>
                                <form id="billingForm" method="post" action="checkout_process.php">
                                    <div class="form-row">
                                        <div class="form-group col-md-12 mb-3">
                                            <label for="name">Payer's Name <span class="required error"></span></label>
                                            <input type="text" class="form-control" id="name" name="name" placeholder="Depositor's Name on Teller" required>
                                        </div>
                                        <div class="form-group col-md-12 mb-3">
                                            <label for="email">Email <span class="required error"></span></label>
                                            <input type="email" class="form-control" id="email" name="email" placeholder="Coordinator's Email" required>
                                        </div>
                                        <div class="form-group col-md-12 mb-3">
                                            <label for="teller_number">Reference <span class="required error"></span></label>
                                            <div class="input-group">
                                                <input type="text" class="form-control" id="teller_number" name="teller_number" placeholder="Province Generated RRR" readonly required>
                                                <div class="input-group-append">
                                                    <button id="generateReferenceCode" class="btn btn-primary" name="generate_reference_code" <?php if ($incompleteRegistration) echo 'disabled'; ?>>Generate Reference Code</button>
                                                </div>
                                            </div>
                                            <div id="successAlert" class="alert alert-success" style="display: none; margin:4px;">
                                                New Reference code generated successfully!
                                            </div>
                                            <!-- Bootstrap Alert for Disabled Reason -->
                                            <div id="disabledAlert" class="alert alert-warning custom-warning" style="display: none;">
                                                <i class="bi bi-exclamation-triangle blink-icon"></i>
                                                <strong>Warning!</strong> You cannot generate a new reference code due to incomplete registrations.
                                                <a href="regcontinue.php" class="btn btn-warning btn-sm ml-2">Complete Registration</a>
                                            </div>

                                            <!-- Custom CSS -->
                                            <style>
                                                .custom-warning {
                                                    background-color: #f8d7da;
                                                    /* Light red background for warning */
                                                    color: #721c24;
                                                    /* Dark red text for better visibility */
                                                    border-color: #f5c6cb;
                                                    /* Red border to match the background */
                                                    display: flex;
                                                    /* Use flexbox for better alignment */
                                                    align-items: center;
                                                    /* Vertically center the items */
                                                    margin: 4px;
                                                }

                                                .blink-icon {
                                                    font-size: 1.5rem;
                                                    /* Increase the icon size */
                                                    margin-right: 0.75rem;
                                                    /* Add some spacing to the right of the icon */
                                                    animation: blink 1s step-start infinite;
                                                    /* Apply the blinking animation */
                                                }

                                                /* Blinking animation */
                                                @keyframes blink {
                                                    0% {
                                                        opacity: 1;
                                                    }

                                                    50% {
                                                        opacity: 0;
                                                    }

                                                    100% {
                                                        opacity: 1;
                                                    }
                                                }
                                            </style>

                                            <!-- Include Bootstrap Icons -->

                                        </div>
                                        <div class="form-group col-md-12 mb-3">
                                            <label for="phone_number">Phone Number <span class="required error"></span></label>
                                            <input type="text" class="form-control" id="phone_number" name="phone_number" maxlength="11" placeholder="Depositor's Contact Number" required>
                                        </div>
                                        <div class="form-group col-md-12 mb-3">
                                            <label for="zone">Zone Category <span class="required error"></span></label>
                                            <input type="text" class="form-control" name="zone" readonly value="<?php echo $_SESSION['zone']; ?>" required>
                                        </div>
                                        <div class="form-group col-md-12 mb-3">
                                            <label for="region">Region <span class="required error"></span></label>
                                            <input type="text" class="form-control" name="region" readonly value="<?php echo $_SESSION['reg']; ?>" required>
                                        </div>
                                        <div class="form-group col-md-12 mb-3">
                                            <label for="province">Province <span class="required error"></span></label>
                                            <input type="text" class="form-control" name="province" readonly value="<?php echo $_SESSION['pro']; ?>" required>
                                        </div>
                                    </div>
                                    <button type="submit" name="checkout" class="btn btn-primary disabled-button" id="checkoutButton" disabled>Proceed to Pay</button>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>

        </div>

        <?php
        include 'conn.php'; // Make sure this file contains your database connection

        // Fetch the modal content from the database
        $stmt = $conn->query("SELECT message FROM modal_content ORDER BY id DESC LIMIT 1");
        $modalContent = $stmt->fetch(PDO::FETCH_ASSOC);
        $message = $modalContent['message'];
        ?>

        <!-- Modal HTML -->
        <!-- <div id="announcementModal" class="modal">
    <div class="modal-content">
        <span class="close-btn" onclick="closeModal()">&times;</span>
        <h2>🎉 Welcome to the New Convention Portal! 🎉</h2>
        <p>
            <?php echo $message; ?>
        </p>
    </div>
</div> -->

        <!-- <div class="toast-container" style="position: absolute; top: 20px; right: 20px;">
   
    <div class="toast" id="myToast" role="alert" aria-live="assertive" aria-atomic="true" data-delay="3000">
        <div class="toast-header">
            <strong class="mr-auto">Welcome Message</strong>
            <small class="text-muted">just now</small>
            <button type="button" class="ml-2 mb-1 close" data-dismiss="toast" aria-label="Close">
                <span aria-hidden="true">&times;</span>
            </button>
        </div>
        <div class="toast-body" id="toastBody">
            <p>Welcome back, <?php echo htmlspecialchars($_SESSION['pro'], ENT_QUOTES, 'UTF-8'); ?>! We are glad to have you here.</p>
        </div>
    </div>
</div> -->


        <!-- /.content-wrapper -->

        <!-- Footer -->
        <?php
        include 'conn.php'; // Ensure this file contains your database connection

        // Fetch footer content from the footer table
        $stmt = $conn->query("SELECT * FROM footer ORDER BY id DESC LIMIT 1");
        $footer = $stmt->fetch(PDO::FETCH_ASSOC);
        $copyrightMessage = $footer['copyright_message'] ?? '&copy; ' . date('Y') . ' Directorate of Teens and Children Education.';
        $eventInfo = $footer['event_info'] ?? 'CO-ORDINATOR\'S EVENT REGISTRATION PORTAL v.1.0.0';
        ?>
        <footer class="main-footer text-sm">
            <div class="text-xs" id="copyright">
                <?php echo $copyrightMessage; ?>
                <div class="float-right d-none d-sm-inline-block">
                    <b><?php echo $eventInfo; ?></b>
                </div>
            </div>
        </footer>

        <!-- ./wrapper -->

        <script>
            document.addEventListener('DOMContentLoaded', function() {
                const form = document.getElementById('billingDetails');
                const checkoutButton = document.getElementById('checkoutButton');
                const generateReferenceButton = document.getElementById('generateReferenceCode');
                const successAlert = document.getElementById('successAlert');

                // Function to check if all fields are filled
                function checkFormCompletion() {
                    const requiredFields = form.querySelectorAll('input[required]');
                    let allFilled = true;

                    requiredFields.forEach(field => {
                        if (field.value.trim() === '' || field.getAttribute('readonly') === 'readonly') {
                            allFilled = false;
                        }
                    });

                    if (allFilled) {
                        checkoutButton.disabled = false;
                        checkoutButton.classList.remove('disabled-button');
                    } else {
                        checkoutButton.disabled = true;
                        checkoutButton.classList.add('disabled-button');
                    }
                }

                // Function to enable checkout button when reference code is generated
                function enableCheckoutButton() {
                    checkoutButton.disabled = false;
                    checkoutButton.classList.remove('disabled-button');
                }

                // Event listener for form inputs
                form.addEventListener('input', checkFormCompletion);

                // Simulating the reference code generation and enabling the button
                generateReferenceButton.addEventListener('click', function() {
                    // Simulate reference code generation
                    setTimeout(function() {
                        // Show success alert
                        successAlert.style.display = 'block';

                        // Enable the checkout button
                        enableCheckoutButton();
                    }, 1000); // Simulate delay for reference code generation
                });
            });
        </script>

        <!-- JavaScript to Show Billing Details Form -->
        <script>
            document.getElementById('checkoutButton2').addEventListener('click', function(event) {
                event.preventDefault(); // Prevent default link behavior
                document.getElementById('billingDetails').style.display = 'block'; // Show the billing details form
            });
        </script>
        <!-- Script to Handle Button Clicks -->
        <script>
            document.addEventListener('DOMContentLoaded', function() {
                // Check if there are incomplete registrations
                var hasIncompleteRegistrations = <?php echo !empty($incompleteRegistration) ? 'true' : 'false'; ?>;
                var generateButton = document.getElementById('generateReferenceCode');
                var disabledAlert = document.getElementById('disabledAlert');
                var referenceCodeInput = document.getElementById('teller_number');
                var checkoutButton = document.getElementById('checkoutButton');

                // Update the state of the Generate Reference Code button and alerts
                function updateGenerateButtonState() {
                    if (hasIncompleteRegistrations) {
                        generateButton.disabled = true;
                        disabledAlert.style.display = 'block';
                    } else {
                        generateButton.disabled = false;
                        disabledAlert.style.display = 'none';
                    }
                }

                // Initial call to set the button state based on incomplete registrations
                updateGenerateButtonState();

                // Event listener for Generate Reference Code button
                generateButton.addEventListener('click', function() {
                    if (generateButton.disabled) {
                        // Prevent action if button is disabled
                        return;
                    }

                    // Generate a new reference code
                    const referenceCode = generateReferenceCode();

                    // Set the generated code in the input field
                    referenceCodeInput.value = referenceCode;

                    // Enable the "Proceed to Checkout" button
                    checkoutButton.disabled = false;

                    // Change the button's color, display "CODE GENERATED," and disable the button
                    generateButton.style.backgroundColor = 'green';
                    generateButton.innerHTML = 'CODE GENERATED';
                    generateButton.disabled = true;

                    // Show a success Bootstrap message and dismiss it automatically
                    const successAlert = document.getElementById('successAlert');
                    successAlert.style.display = 'block';
                    setTimeout(function() {
                        successAlert.style.display = 'none';
                    }, 5000); // Hide the message after 5 seconds

                    // Store the reference code in local storage
                    localStorage.setItem(referenceCode, 'exists');
                });

                // Function to generate the reference code
                function generateReferenceCode() {
                    let referenceCode;
                    do {
                        referenceCode = generateRandomCode(); // Generate a code
                    } while (isReferenceCodeExists(referenceCode));

                    return referenceCode;
                }

                // Function to check if the reference code exists in local storage
                function isReferenceCodeExists(code) {
                    return localStorage.getItem(code) !== null;
                }

                // Generate a random code
                function generateRandomCode() {
                    const characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
                    let code = '';
                    for (let i = 0; i < 11; i++) {
                        const randomIndex = Math.floor(Math.random() * characters.length);
                        code += characters.charAt(randomIndex);
                    }
                    return code;
                }

                // Handle logout event (when the user logs out)
                function handleLogout() {
                    // Remove the reference codes from local storage
                    localStorage.clear();
                }
            });
        </script>

        <script>
            $(document).ready(function() {
                $('#notificationDropdown').on('click', function() {
                    $.ajax({
                        url: 'fetch_notifications.php',
                        type: 'GET',
                        data: {
                            province: '<?php echo $_SESSION['pro']; ?>'
                        },
                        dataType: 'json',
                        success: function(data) {
                            console.log('Fetched notifications:', data);
                            let notificationList = $('#notificationList');
                            notificationList.empty();

                            if (data.length === 0) {
                                notificationList.append('<div class="dropdown-item">No notifications</div>');
                            } else {
                                data.forEach(notification => {
                                    let createdDate = new Date(notification.created_at);
                                    let formattedDate = formatDate(createdDate);
                                    let timeAgo = timeSince(createdDate);
                                    let unreadBadge = notification.is_read === 0 ? '<span class="badge badge-danger">Unread</span>' : '';

                                    notificationList.append(`
                            <a class="dropdown-item" href="read_notification.php?id=${notification.id}">
                                ${unreadBadge} ${notification.message}
                                <small class="text-muted">${formattedDate} (${timeAgo})</small>
                            </a>
                        `);
                                });
                            }

                            $('.badge-danger').text(data.length);
                        },
                        error: function(xhr, status, error) {
                            console.error('Error loading notifications:', error);
                        }
                    });
                });
            });

            function formatDate(date) {
                const options = {
                    day: 'numeric',
                    month: 'short',
                    year: 'numeric'
                };
                let day = date.getDate();
                let month = date.toLocaleString('default', {
                    month: 'short'
                });
                let suffix = day % 10 === 1 && day !== 11 ? 'st' :
                    day % 10 === 2 && day !== 12 ? 'nd' :
                    day % 10 === 3 && day !== 13 ? 'rd' : 'th';
                return `${day}${suffix} ${month}, ${date.getFullYear()}`;
            }

            function timeSince(date) {
                const seconds = Math.floor((new Date() - date) / 1000);
                let interval = Math.floor(seconds / 31536000);
                if (interval > 1) return interval + " years ago";
                interval = Math.floor(seconds / 2592000);
                if (interval > 1) return interval + " months ago";
                interval = Math.floor(seconds / 86400);
                if (interval > 1) return interval + " days ago";
                interval = Math.floor(seconds / 3600);
                if (interval > 1) return interval + " hours ago";
                interval = Math.floor(seconds / 60);
                if (interval > 1) return interval + " minutes ago";
                return seconds + " seconds ago";
            }
        </script>


<script>
    // Function to show the toast
    function showToast() {
        const toast = document.getElementById('myToast');
        $(toast).toast('show'); // Manually trigger the toast
    }

    // Function to hide the toast and store it in localStorage
    function hideToast() {
        localStorage.setItem('toastShown', 'true'); // Store in localStorage
    }

    // Auto-trigger the toast on page load if it has not been shown before
    window.onload = function() {
        if (!localStorage.getItem('toastShown')) {
            showToast();
        }
    };

    // Event listener to detect when toast is closed
    document.addEventListener('DOMContentLoaded', function () {
        const toast = document.getElementById('myToast');
        $(toast).on('hidden.bs.toast', function () {
            hideToast();
        });
    });
</script>
        <script>
            document.addEventListener('DOMContentLoaded', function() {
                document.getElementById('videoContainer').addEventListener('click', function(event) {
                    if (event.target && event.target.classList.contains('play-button')) {
                        const videoId = event.target.getAttribute('data-id');
                        const videoTitle = event.target.getAttribute('data-title');

                        // Set the iframe src
                        const videoFrame = document.getElementById('videoFrame');
                        videoFrame.src = `https://www.youtube.com/embed/${videoId}?autoplay=1`;

                        // Set the modal title
                        document.getElementById('videoModalLabel').textContent = videoTitle;

                        // Show the modal
                        $('#videoModal').modal('show');
                    }
                });

                // Clear the iframe src when the modal is closed
                $('#videoModal').on('hidden.bs.modal', function() {
                    document.getElementById('videoFrame').src = '';
                });
            });
        </script>

        <script>
            document.addEventListener("DOMContentLoaded", function() {
                // Check if the modal has been closed previously
                if (!localStorage.getItem("modalClosed")) {
                    // Show the modal if not closed
                    document.getElementById("announcementModal").style.display = "block";
                }
            });

            function closeModal() {
                // Hide the modal
                document.getElementById("announcementModal").style.display = "none";
                // Set a flag in localStorage to indicate that the modal has been closed
                localStorage.setItem("modalClosed", "true");
            }
        </script>
        <script>
            document.addEventListener('DOMContentLoaded', function() {
    const toggle = document.getElementById('theme-toggle');
    const icon = document.getElementById('theme-icon');

    function applyDarkMode() {
        document.body.classList.add('dark-mode');
        document.body.classList.remove('light-mode');
        if (icon) {
            icon.classList.remove('fa-sun');
            icon.classList.add('fa-moon');
        }
        localStorage.setItem('theme', 'dark');
    }

    function applyLightMode() {
        document.body.classList.add('light-mode');
        document.body.classList.remove('dark-mode');
        if (icon) {
            icon.classList.remove('fa-moon');
            icon.classList.add('fa-sun');
        }
        localStorage.setItem('theme', 'light');
    }

    // Check and apply the saved theme
    if (localStorage.getItem('theme') === 'dark') {
        applyDarkMode();
    } else {
        applyLightMode();
    }

    // Toggle event listener
    if (toggle) {
        toggle.addEventListener('click', function() {
            if (document.body.classList.contains('dark-mode')) {
                applyLightMode();
            } else {
                applyDarkMode();
            }
        });
    }
});

        </script>

        <!-- Scripts -->
        <script>
        $(document).ready(function() {
            $('#notificationDropdown').on('click', function() {
                $.ajax({
                    url: 'fetch_notifications.php',
                    type: 'GET',
                    data: {
                        province: '<?php echo $_SESSION['pro']; ?>'
                    },
                    dataType: 'json',
                    success: function(data) {
                        console.log('Fetched notifications:', data);
                        let notificationList = $('#notificationList');
                        notificationList.empty();

                        if (data.length === 0) {
                            notificationList.append(
                                '<div class="dropdown-item">No Notifications</div>');
                        } else {
                            data.forEach(notification => {
                                let createdDate = new Date(notification.created_at);
                                let formattedDate = formatDate(createdDate);
                                let timeAgo = timeSince(createdDate);
                                let unreadBadge = notification.is_read === 0 ?
                                    '<span class="badge badge-danger">Unread</span>' :
                                    '';

                                notificationList.append(`
                            <a class="dropdown-item" href="read_notification.php?id=${notification.id}">
                                ${unreadBadge} ${notification.message}
                                <small class="text-muted">${formattedDate} (${timeAgo})</small>
                            </a>
                        `);
                            });
                        }

                        $('.badge-danger').text(data.length);
                    },
                    error: function(xhr, status, error) {
                        console.error('Error loading notifications:', error);
                    }
                });
            });
        });

        function formatDate(date) {
            const options = {
                day: 'numeric',
                month: 'short',
                year: 'numeric'
            };
            let day = date.getDate();
            let month = date.toLocaleString('default', {
                month: 'short'
            });
            let suffix = day % 10 === 1 && day !== 11 ? 'st' :
                day % 10 === 2 && day !== 12 ? 'nd' :
                day % 10 === 3 && day !== 13 ? 'rd' : 'th';
            return `${day}${suffix} ${month}, ${date.getFullYear()}`;
        }

        function timeSince(date) {
            const seconds = Math.floor((new Date() - date) / 1000);
            let interval = Math.floor(seconds / 31536000);
            if (interval > 1) return interval + " years ago";
            interval = Math.floor(seconds / 2592000);
            if (interval > 1) return interval + " months ago";
            interval = Math.floor(seconds / 86400);
            if (interval > 1) return interval + " days ago";
            interval = Math.floor(seconds / 3600);
            if (interval > 1) return interval + " hours ago";
            interval = Math.floor(seconds / 60);
            if (interval > 1) return interval + " minutes ago";
            return seconds + " seconds ago";
        }
    </script>
    <!-- Scripts -->
    <script src="plugins/jquery/jquery.min.js"></script>
    <script src="plugins/bootstrap/js/bootstrap.bundle.min.js"></script>
    <script src="plugins/intl-tel-input-17.0.0/build/js/intlTelInput.min.js"></script>
    <script src="plugins/sweetalert2/sweetalert2.min.js"></script>
    <script src="plugins/password-requirement/js/jquery.passwordRequirements.min.js"></script>
    <script src="dist/js/adminlte.min.js"></script>
    <script defer src="scripts/cookies/cookieconsent.js"></script>
    <script defer src="scripts/cookies/cookieconsent-init.js"></script>
    <script src="plugins/jquery-validation/jquery.validate.min.js"></script>
    <script src="plugins/jquery-validation/additional-methods.min.js"></script>
    <!-- Include jQuery and Bootstrap JS -->

    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.3/dist/umd/popper.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

    <script src="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.min.js"></script>




</body>

</html>